@@ -29,7 +29,6 @@
  */
 
 #if defined(_MSC_VER) || defined(__MINGW32__)
- #define WIN32_LEAN_AND_MEAN
  #include <windows.h>
 #endif
 
@@ -38,7 +37,7 @@ extern "C"
 {
 #endif
 
-#if defined(__linux__) && !defined(_GNU_SOURCE)
+#if (defined(__linux__) || defined(__FreeBSD__)) && !defined(_GNU_SOURCE)
 #define _GNU_SOURCE 1
 #endif
 
@@ -460,7 +459,7 @@ void* System_moFiles(const char *directory)
 {
   int i,count;
   void *res;
-  struct dirent **files;
+  struct dirent **files = NULL;
   select_from_dir = directory;
   count = scandir(directory, &files, file_select_mo, NULL);
   res = mmc_mk_nil();
@@ -469,6 +468,7 @@ void* System_moFiles(const char *directory)
     res = mmc_mk_cons(mmc_mk_scon(files[i]->d_name),res);
     free(files[i]);
   }
+  free(files);
   return res;
 }
 #endif
@@ -488,7 +488,7 @@ void* System_mocFiles(const char *directory)
 {
   int i,count;
   void *res;
-  struct dirent **files;
+  struct dirent **files = NULL;
   select_from_dir = directory;
   count = scandir(directory, &files, file_select_moc, NULL);
   res = mmc_mk_nil();
@@ -497,6 +497,7 @@ void* System_mocFiles(const char *directory)
     res = mmc_mk_cons(mmc_mk_scon(files[i]->d_name),res);
     free(files[i]);
   }
+  free(files);
   return res;
 }
 #endif
@@ -604,7 +605,7 @@ void* System_subDirectories(const char *directory)
 {
   int i,count;
   void *res;
-  struct dirent **files;
+  struct dirent **files = NULL;
   select_from_dir = directory;
   count = scandir(directory, &files, file_select_directories, NULL);
   res = mmc_mk_nil();
@@ -613,6 +614,7 @@ void* System_subDirectories(const char *directory)
     res = mmc_mk_cons(mmc_mk_scon(files[i]->d_name),res);
     free(files[i]);
   }
+  free(files);
   return res;
 }
 #endif
@@ -721,6 +723,13 @@ extern const char* System_modelicaPlatform()
   return CONFIG_MODELICA_SPEC_PLATFORM;
 }
 
+/**
+ * @brief Returns platform OpenModelica is compiled for.
+ *
+ * Returns CONFIG_OPENMODELICA_SPEC_PLATFORM defined in omc_config.h
+ *
+ * @return const char* platform specifier
+ */
 extern const char* System_openModelicaPlatform()
 {
   return CONFIG_OPENMODELICA_SPEC_PLATFORM;
