@@ -36,6 +36,8 @@
 #include "systemimpl.h"
 #include "meta/meta_modelica.h"
 
+#include "util/omc_file.h"
+
 /* this is defined in systemimplmisc.h/cpp */
 extern char* _replace(const char* source_str, const char* search_str, const char* replace_str);
 
@@ -78,7 +80,7 @@ static void free_printimpl(void *data)
   free(members);
 }
 
-#if !defined(OMC_NO_THREADS)
+#if defined(OM_HAVE_PTHREADS)
 #include <pthread.h>
 
 pthread_once_t printimpl_once_create_key = PTHREAD_ONCE_INIT;
@@ -92,14 +94,14 @@ static void make_key()
 
 static print_members* getMembers(threadData_t *threadData)
 {
-#if defined(OMC_NO_THREADS)
+#if !defined(OM_HAVE_PTHREADS)
   static
 #endif
   print_members *res = NULL;
   if (threadData && threadData->localRoots[LOCAL_ROOT_PRINT_MO]) {
     return threadData->localRoots[LOCAL_ROOT_PRINT_MO];
   }
-#if !defined(OMC_NO_THREADS)
+#if defined(OM_HAVE_PTHREADS)
   pthread_once(&printimpl_once_create_key,make_key);
   res = (print_members*) pthread_getspecific(printimplKey);
 #endif
@@ -340,9 +342,9 @@ static int PrintImpl__writeBuf(threadData_t *threadData,const char* filename)
   /* open the file */
   /* adrpo: 2010-09-22 open the file in BINARY mode as otherwise \r\n becomes \r\r\n! */
 #if defined(__APPLE_CC__)||defined(__MINGW32__)||defined(__MINGW64__)
-  unlink(filename);
+  omc_unlink(filename);
 #endif
-  file = fopen(filename,fileOpenMode);
+  file = omc_fopen(filename, fileOpenMode);
   if (file == NULL) {
     const char *c_tokens[1]={filename};
     c_add_message(NULL,21, /* WRITING_FILE_ERROR */
@@ -431,9 +433,9 @@ static int PrintImpl__writeBufConvertLines(threadData_t *threadData,const char *
   /* open the file */
   /* adrpo: 2010-09-22 open the file in BINARY mode as otherwise \r\n becomes \r\r\n! */
 #if defined(__APPLE_CC__)||defined(__MINGW32__)||defined(__MINGW64__)
-  unlink(filename);
+  omc_unlink(filename);
 #endif
-  file = fopen(filename,fileOpenMode);
+  file = omc_fopen(filename,fileOpenMode);
   if (file == NULL) {
     const char *c_tokens[1]={filename};
     c_add_message(NULL,21, /* WRITING_FILE_ERROR */
@@ -455,6 +457,9 @@ static int PrintImpl__writeBufConvertLines(threadData_t *threadData,const char *
   /* on Windows change the backslashes to forward slashes */
   strtmp = _replace(filename, "\\", "/");
 #endif
+  if (getenv("OPENMODELICA_BACKEND_STUBS")) {
+    filename = SystemImpl__basename(filename);
+  }
   fprintf(file,"#ifdef OMC_BASE_FILE\n"
                "  #define OMC_FILE OMC_BASE_FILE\n"
                "#else\n"
