@@ -101,12 +101,15 @@ const char *FLAG_NAME[FLAG_MAX+1] = {
   /* FLAG_LSS_MAX_DENSITY */              "lssMaxDensity",
   /* FLAG_LSS_MIN_SIZE */                 "lssMinSize",
   /* FLAG_LV */                           "lv",
+  /* FLAG_LV_MAX_WARN */                  "lvMaxWarn",
   /* FLAG_LV_TIME */                      "lv_time",
+  /* FLAG_LV_SYSTEM */                    "lv_system",
   /* FLAG_MAX_BISECTION_ITERATIONS */     "mbi",
   /* FLAG_MAX_EVENT_ITERATIONS */         "mei",
   /* FLAG_MAX_ORDER */                    "maxIntegrationOrder",
   /* FLAG_MAX_STEP_SIZE */                "maxStepSize",
   /* FLAG_MEASURETIMEPLOTFORMAT */        "measureTimePlotFormat",
+  /* FLAG_NEWTON_DIAGNOSTICS */           "newtonDiagnostics",
   /* FLAG_NEWTON_FTOL */                  "newtonFTol",
   /* FLAG_NEWTON_MAX_STEP_FACTOR */       "newtonMaxStepFactor",
   /* FLAG_NEWTON_XTOL */                  "newtonXTol",
@@ -136,6 +139,7 @@ const char *FLAG_NAME[FLAG_MAX+1] = {
   /* FLAG_R */                            "r",
   /* FLAG_DATA_RECONCILE  */              "reconcile",
   /* FLAG_DATA_RECONCILE_BOUNDARY */      "reconcileBoundaryConditions",
+  /* FLAG_DATA_RECONCILE_STATE */         "reconcileState",
   /* FLAG_SR */                           "gbm",
   /* FLAG_SR_CTRL */                      "gbctrl",
   /* FLAG_SR_ERR */                       "gberr",
@@ -232,12 +236,15 @@ const char *FLAG_DESC[FLAG_MAX+1] = {
   /* FLAG_LSS_MAX_DENSITY */              "[double (default " EXPANDSTRING(DEFAULT_FLAG_LSS_MAX_DENSITY) ")] value specifies the maximum density for using a linear sparse solver",
   /* FLAG_LSS_MIN_SIZE */                 "[int (default " EXPANDSTRING(DEFAULT_FLAG_LSS_MIN_SIZE) ")] value specifies the minimum system size for using a linear sparse solver",
   /* FLAG_LV */                           "[string list] value specifies the logging level",
+  /* FLAG_LV_MAX_WARN */                  "[int (default " EXPANDSTRING(DEFAULT_FLAG_LV_MAX_WARN) ")] maximum times repeating warnings will be displayed",
   /* FLAG_LV_TIME */                      "[double list] specifying time interval to allow loging in",
+  /* FLAG_LV_SYSTEM */                    "[int list] list of system indices for which solver logs are shown (by default logs for all systems are shown)",
   /* FLAG_MAX_BISECTION_ITERATIONS */     "[int (default 0)] value specifies the maximum number of bisection iterations for state event detection or zero for default behavior",
   /* FLAG_MAX_EVENT_ITERATIONS */         "[int (default 20)] value specifies the maximum number of event iterations",
   /* FLAG_MAX_ORDER */                    "value specifies maximum integration order for supported solver",
   /* FLAG_MAX_STEP_SIZE */                "value specifies maximum absolute step size for supported solver",
   /* FLAG_MEASURETIMEPLOTFORMAT */        "value specifies the output format of the measure time functionality",
+  /* FLAG_NEWTON_DIAGNOSTICS */           "Run newton diagnostics to improve start values for non-linear systems",
   /* FLAG_NEWTON_FTOL */                  "[double (default 1e-12)] tolerance respecting residuals for updating solution vector in Newton solver",
   /* FLAG_NEWTON_MAX_STEP_FACTOR */       "[double (default 1e12)] maximum newton step factor mxnewtstep = maxStepFactor * norm2(xScaling). Used currently only by KINSOL.",
   /* FLAG_NEWTON_XTOL */                  "[double (default 1e-12)] tolerance respecting newton correction (delta_x) for updating solution vector in Newton solver",
@@ -267,14 +274,15 @@ const char *FLAG_DESC[FLAG_MAX+1] = {
   /* FLAG_R */                            "value specifies a new result file than the default Model_res.mat",
   /* FLAG_DATA_RECONCILE */               "Run the Data Reconciliation numerical computation algorithm for constrained equations",
   /* FLAG_DATA_RECONCILE_BOUNDARY */      "Run the Data Reconciliation numerical computation algorithm for boundary condition equations",
+  /* FLAG_DATA_RECONCILE_STATE */         "Run the State Estimation numerical computation algorithm for constrained equations",
   /* FLAG_SR */                           "Value specifies the chosen solver of solver gbode (single-rate, slow states integrator)",
   /* FLAG_SR_CTRL */                      "Step size control of solver gbode (single-rate, slow states integrator)",
-  /* FLAG_SR_ERR */                       "Error estimation done by Richardson extrapolation  (-gberr=1) of solver gbode (single-rate, slow states integrator)",
+  /* FLAG_SR_ERR */                       "Error estimation method for solver gbode (single-rate, slow states integrator).",
   /* FLAG_SR_INT */                       "Interpolation method of solver gbode (single-rate, slow states integrator)",
   /* FLAG_SR_NLS */                       "Non-linear solver method of solver gbode (single-rate, slow states integrator)",
   /* FLAG_MR */                           "Value specifies the chosen solver of solver gbode (multi-rate, fast states integrator)",
   /* FLAG_MR_CTRL */                      "Step size control of solver gbode (multi-rate, fast states integrator)",
-  /* FLAG_MR_ERR */                       "Error estimation done by Richardson extrapolation  (-gberr=1) of solver gbode (multi-rate, fast states integrator)",
+  /* FLAG_MR_ERR */                       "Error estimation method for gbode solver (multi-rate, fast states integrator).",
   /* FLAG_MR_INT */                       "Interpolation method of solver gbode (multi-rate, fast states integrator)",
   /* FLAG_MR_NLS */                       "Non-linear solver method of solver gbode (multi-rate, fast states integrator)",
   /* FLAG_MR_PAR */                       "Define percentage of states for the fast states selection of solver gbode",
@@ -417,7 +425,7 @@ const char *FLAG_DETAILED_DESC[FLAG_MAX+1] = {
   "  * iterativ - default, sparse iterativ linear solver with fallback case to dense solver\n"
   "  * dense - dense linear solver, SUNDIALS default method",
   /* FLAG_INITIAL_STEP_SIZE */
-  "  Value specifies an initial step size, used by the methods: dassl, ida",
+  "  Value specifies an initial step size, used by the methods: dassl, ida, gbode",
   /* FLAG_INPUT_CSV */
   "  Value specifies an csv-file with inputs for the simulation/optimization of the model",
   /* FLAG_INPUT_FILE_STATES */
@@ -464,10 +472,15 @@ const char *FLAG_DETAILED_DESC[FLAG_MAX+1] = {
   /* FLAG_LV */
   "  Value (a comma-separated String list) specifies which logging levels to\n"
   "  enable. Multiple options can be enabled at the same time.",
+  /* FLAG_LV_MAX_WARN */
+  "  Maximum number of times some repeating warnings are displayed.\n"
+  "  Default value " EXPANDSTRING(DEFAULT_FLAG_LV_MAX_WARN) ".",
   /* FLAG_LV_TIME */
   "  Interval (a comma-separated Double list with two elements) specifies in which\n"
   "  time interval logging is active. Doesn't affect LOG_STDOUT, LOG_ASSERT, and\n"
   "  LOG_SUCCESS, LOG_STATS, LOG_STATS_V.",
+  /* FLAG_LV_SYSTEM */
+  "  Value is a comma-separated list of equation indices (available in the transformational debugger) for which solver logs are shown (by default logs for all systems are shown)",
   /* FLAG_MAX_BISECTION_ITERATIONS */
   "  Value specifies the maximum number of bisection iterations for state event\n"
   "  detection or zero for default behavior",
@@ -477,7 +490,7 @@ const char *FLAG_DETAILED_DESC[FLAG_MAX+1] = {
   /* FLAG_MAX_ORDER */
   "  Value specifies maximum integration order, used by the methods: dassl, ida.",
   /* FLAG_MAX_STEP_SIZE */
-  "  Value specifies maximum absolute step size, used by the methods: dassl, ida.",
+  "  Value specifies maximum absolute step size, used by the methods: dassl, ida, gbode.",
   /* FLAG_MEASURETIMEPLOTFORMAT */
   "  Value specifies the output format of the measure time functionality:\n\n"
   "  * svg\n"
@@ -485,6 +498,9 @@ const char *FLAG_DETAILED_DESC[FLAG_MAX+1] = {
   "  * ps\n"
   "  * gif\n"
   "  * ...",
+  /* FLAG_NEWTON_DIAGNOSTICS */
+  "  Implementation of \"On the choice of initial guesses for the Newton-Raphson algorithm.\"\n"
+  "  See: https://doi.org/10.1016/j.amc.2021.125991",
   /* FLAG_NEWTON_FTOL */
   "  Tolerance respecting residuals for updating solution vector in Newton solver.\n"
   "  Solution is accepted if the (scaled) 2-norm of the residuals is smaller than the tolerance newtonFTol and the (scaled) newton correction (delta_x) is smaller than the tolerance newtonXTol.\n"
@@ -565,13 +581,18 @@ const char *FLAG_DETAILED_DESC[FLAG_MAX+1] = {
   "  Run the Data Reconciliation numerical computation algorithm for constrained equations",
   /* FLAG_DATA_RECONCILE_BOUNDARY */
   "  Run the Data Reconciliation numerical computation algorithm for boundary condition equations",
+  /* FLAG_DATA_RECONCILE_STATE */
+  "  Run the State Estimation numerical computation algorithm for constrained equations",
   /* FLAG_SR */
   "  Value specifies the chosen solver of solver gbode (single-rate, slow states integrator).",
   /* FLAG_SR_CTRL */
   "  Step size control of solver gbode (single-rate, slow states integrator).",
   /* FLAG_SR_ERR */
-  "  Error estimation done by Richardson extrapolation (-gberr=1) of solver gbode\n"
-  "  (single-rate, slow states integrator).",
+  "  Error estimation method for solver gbode (single-rate, slow states integrator)\n"
+  "  Possible values:\n\n"
+  "    * default    - depending on the Runge-Kutta method\n"
+  "    * richardson - Richardson extrapolation\n"
+  "    * embedded   - Embedded scheme\n",
   /* FLAG_SR_INT */
   "  Interpolation method of solver gbode (single-rate, slow states integrator).",
   /* FLAG_SR_NLS */
@@ -582,8 +603,11 @@ const char *FLAG_DETAILED_DESC[FLAG_MAX+1] = {
   /* FLAG_MR_CTRL */
   "  Step size control of solver gbode (multi-rate, fast states integrator).",
   /* FLAG_MR_ERR */
-  "  Error estimation done by Richardson extrapolation  (-gberr=1) of solver gbode\n"
-  "  (multi-rate, fast states integrator).",
+  "  Error estimation method for solver gbode (multi-rate, fast states integrator)\n"
+  "  Possible values:\n\n"
+  "    * default    - depending on the Runge-Kutta method\n"
+  "    * richardson - Richardson extrapolation\n"
+  "    * embedded   - Embedded scheme\n",
   /* FLAG_MR_INT */
   "  Interpolation method of solver gbode (multi-rate, fast states integrator).",
   /* FLAG_MR_NLS */
@@ -686,12 +710,15 @@ const flag_repeat_policy FLAG_REPEAT_POLICIES[FLAG_MAX] = {
   /* FLAG_LSS_MAX_DENSITY */              FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_LSS_MIN_SIZE */                 FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_LV */                           FLAG_REPEAT_POLICY_REPLACE,
+  /* FLAG_LV_MAX_WARN */                  FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_LV_TIME */                      FLAG_REPEAT_POLICY_FORBID,
+  /* FLAG_LV_SYSTEM */                    FLAG_REPEAT_POLICY_COMBINE,
   /* FLAG_MAX_BISECTION_ITERATIONS */     FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_MAX_EVENT_ITERATIONS */         FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_MAX_ORDER */                    FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_MAX_STEP_SIZE */                FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_MEASURETIMEPLOTFORMAT */        FLAG_REPEAT_POLICY_FORBID,
+  /* FLAG_NEWTON_DIAGNOSTICS */           FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_NEWTON_FTOL */                  FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_NEWTON_MAX_STEP_FACTOR */       FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_NEWTON_XTOL */                  FLAG_REPEAT_POLICY_FORBID,
@@ -721,6 +748,7 @@ const flag_repeat_policy FLAG_REPEAT_POLICIES[FLAG_MAX] = {
   /* FLAG_R */                            FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_DATA_RECONCILE  */              FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_DATA_RECONCILE_BOUNDARY */      FLAG_REPEAT_POLICY_FORBID,
+  /* FLAG_DATA_RECONCILE_STATE  */        FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_SR */                           FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_SR_CTRL */                      FLAG_REPEAT_POLICY_FORBID,
   /* FLAG_SR_ERR */                       FLAG_REPEAT_POLICY_FORBID,
@@ -816,12 +844,15 @@ const int FLAG_TYPE[FLAG_MAX] = {
   /* FLAG_LSS_MAX_DENSITY */              FLAG_TYPE_OPTION,
   /* FLAG_LSS_MIN_SIZE */                 FLAG_TYPE_OPTION,
   /* FLAG_LV */                           FLAG_TYPE_OPTION,
+  /* FLAG_LV_MAX_WARN */                  FLAG_TYPE_OPTION,
   /* FLAG_LV_TIME */                      FLAG_TYPE_OPTION,
+  /* FLAG_LV_SYSTEM */                    FLAG_TYPE_OPTION,
   /* FLAG_MAX_BISECTION_ITERATIONS */     FLAG_TYPE_OPTION,
   /* FLAG_MAX_EVENT_ITERATIONS */         FLAG_TYPE_OPTION,
   /* FLAG_MAX_ORDER */                    FLAG_TYPE_OPTION,
   /* FLAG_MAX_STEP_SIZE */                FLAG_TYPE_OPTION,
   /* FLAG_MEASURETIMEPLOTFORMAT */        FLAG_TYPE_OPTION,
+  /* FLAG_NEWTON_DIAGNOSTICS */           FLAG_TYPE_FLAG,
   /* FLAG_NEWTON_FTOL */                  FLAG_TYPE_OPTION,
   /* FLAG_NEWTON_MAX_STEP_FACTOR */       FLAG_TYPE_OPTION,
   /* FLAG_NEWTON_XTOL */                  FLAG_TYPE_OPTION,
@@ -851,6 +882,7 @@ const int FLAG_TYPE[FLAG_MAX] = {
   /* FLAG_R */                            FLAG_TYPE_OPTION,
   /* FLAG_DATA_RECONCILE */               FLAG_TYPE_FLAG,
   /* FLAG_DATA_RECONCILE_BOUNDARY */      FLAG_TYPE_FLAG,
+  /* FLAG_DATA_RECONCILE_STATE */         FLAG_TYPE_FLAG,
   /* FLAG_SR */                           FLAG_TYPE_OPTION,
   /* FLAG_SR_CTRL */                      FLAG_TYPE_OPTION,
   /* FLAG_SR_ERR */                       FLAG_TYPE_OPTION,
@@ -917,6 +949,8 @@ const char *GB_METHOD_NAME[RK_MAX] = {
   /* RK_DOPRI45 */       "dopri45",
   /* RK_DOPRISSC1 */     "dopriSsc1",
   /* RK_DOPRISSC2 */     "dopriSsc2",
+  /* RK_TSIT5 */         "tsit5",
+  /* RK_RUNGEKUTTA */    "rungekutta",
   /* RK_RKSSC */         "rungekuttaSsc"
 };
 
@@ -963,6 +997,8 @@ const char *GB_METHOD_DESC[RK_MAX] = {
   /* RK_DOPRI45 */       "Explicit Runge-Kutta method Dormand-Prince (order 5)",
   /* RK_DOPRISSC1 */     "Explicit Runge-Kutta method Dormand-Prince with large stability region (order 1)",
   /* RK_DOPRISSC2 */     "Explicit Runge-Kutta method Dormand-Prince with large stability region (order 2)",
+  /* RK_TSIT5 */         "Explicit Runge-Kutta method from Tsitouras (order 5)",
+  /* RK_RUNGEKUTTA */    "Explicit classical Runge-Kutta method (order 4)",
   /* RK_RKSSC */         "Explicit Runge-Kutta method with large stabiliy region (order 1)"
 };
 
@@ -982,6 +1018,7 @@ const char *GB_CTRL_METHOD_NAME[GB_CTRL_MAX] = {
   /* GB_CTRL_UNKNOWN */   "unknown",
   /* GB_CTRL_I */         "i",
   /* GB_CTRL_PI */        "pi",
+  /* GB_CTRL_PID */       "pid",
   /* GB_CTRL_CNST */      "const"
 };
 
@@ -989,6 +1026,7 @@ const char *GB_CTRL_METHOD_DESC[GB_CTRL_MAX] = {
   /* GB_CTRL_UNKNOWN */   "unknown",
   /* GB_CTRL_I */         "I controller for step size",
   /* GB_CTRL_PI */        "PI controller for step size",
+  /* GB_CTRL_PID */       "PID controller for step size",
   /* GB_CTRL_CNST */      "Constant step size"
 };
 
