@@ -198,10 +198,17 @@ int SimulationMessageModel::getDepth(const QModelIndex &index) const
 void SimulationMessageModel::insertSimulationMessage(SimulationMessage *pSimulationMessage)
 {
   if (pSimulationMessage) {
+    // check scroll position before adding the message
+    auto pVerticalScrollBar = mpSimulationOutputWidget->getSimulationOutputTree()->verticalScrollBar();
+    const bool atBottom = pVerticalScrollBar->value() == pVerticalScrollBar->maximum();
     int row = mpRootSimulationMessage->children().size();
     beginInsertRows(QModelIndex(), row, row);
     mpRootSimulationMessage->insertChild(row, pSimulationMessage);
     endInsertRows();
+    // scroll to bottom
+    if (atBottom) {
+      mpSimulationOutputWidget->getSimulationOutputTree()->scrollToBottom();
+    }
   }
 }
 
@@ -244,7 +251,7 @@ QModelIndex SimulationMessageModel::simulationMessageIndexHelper(const Simulatio
     <message stream="LOG_STATS" type="info" text="    0 state events" />
     <message stream="LOG_STATS" type="info" text="    0 time events" />
   </message>
-  <message stream="stdout" type="info" text="output text">
+  <message stream="LOG_STDOUT" type="info" text="output text">
     <used index="2" />
   </message>
   */
@@ -314,7 +321,7 @@ void SimulationOutputHandler::parseSimulationOutput(const QString &output)
             } else {
               mpSimulationMessage = new SimulationMessage;
             }
-            mpSimulationMessage->mStream = "stdout";
+            mpSimulationMessage->mStream = "LOG_STDOUT";
             mpSimulationMessage->mType = StringHandler::OMEditInfo;
             mpSimulationMessage->mText = QString("Reached display limit");
             mpSimulationMessage->mLevel = mLevel;
@@ -335,7 +342,7 @@ void SimulationOutputHandler::parseSimulationOutput(const QString &output)
             mpSimulationOutputWidget->embeddedServerInitialized();
           }
           if (mpSimulationOutputWidget->isOutputStructured()) {
-            mpSimulationMessage->mText = Qt::convertFromPlainText(attributes.value("text").toString());
+            mpSimulationMessage->mText = Qt::convertFromPlainText(attributes.value("text").toString(), Qt::WhiteSpaceNormal);
           } else {
             mpSimulationMessage->mText = attributes.value("text").toString();
           }
@@ -367,6 +374,7 @@ void SimulationOutputHandler::parseSimulationOutput(const QString &output)
       } else if (mXmlStreamReader.name() == "status") {
         int progress = attributes.value("progress").toInt();
         mpSimulationOutputWidget->getProgressBar()->setValue(progress/100);
+        mpSimulationOutputWidget->updateMessageTabProgress();
       }
     } else if (token == QXmlStreamReader::EndElement) {
       if (mXmlStreamReader.name() == "message") {
