@@ -38,6 +38,7 @@
 #include "Helper.h"
 #include "Utilities.h"
 #include "Util/ResourceCache.h"
+#include "om_format.h"
 
 #include <QtCore/qmath.h>
 #include <QDir>
@@ -1575,10 +1576,14 @@ void StringHandler::fillEncodingComboBox(QComboBox *pEncodingComboBox)
 
 QStringList StringHandler::makeVariableParts(QString variable)
 {
+  /* Do not split quoted variable.
+   * See https://github.com/OpenModelica/OpenModelica/issues/10599#issuecomment-2077331404
+   */
+  QRegularExpression re("\\.(?=(?:[^\']*\'[^\']*\')*[^\']*$)(?![^\\[\\]]*\\])");
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
-  return variable.split(QRegExp("\\.(?![^\\[\\]]*\\])"), Qt::SkipEmptyParts);
+  return variable.split(re, Qt::SkipEmptyParts);
 #else // QT_VERSION_CHECK
-  return variable.split(QRegExp("\\.(?![^\\[\\]]*\\])"), QString::SkipEmptyParts);
+  return variable.split(re, QString::SkipEmptyParts);
 #endif // QT_VERSION_CHECK
 }
 
@@ -1799,19 +1804,20 @@ bool StringHandler::isFileWritAble(QString filePath)
 }
 
 /*!
- * \brief StringHandler::containsSpace
- * Returns true if string contains a space.
- * \param str
+ * \brief StringHandler::nameContainsComma
+ * Checks if the name contains the comma.
+ * Quoted identifiers are allowed to have comma in them.
+ * \param name
  * \return
  */
-bool StringHandler::containsSpace(QString str)
+bool StringHandler::nameContainsComma(const QString &name)
 {
-  for (int i = 0 ; i < str.size() ; i++) {
-    if (str.at(i).isSpace()) {
-      return true;
-    }
+  QString str = name.trimmed();
+  if (str.contains(',') && !(str.startsWith('\'') && str.endsWith('\''))) {
+    return true;
+  } else {
+    return false;
   }
-  return false;
 }
 
 /*!
@@ -1915,22 +1921,16 @@ QString StringHandler::insertClassAtPosition(QString parentClassText, QString ch
 
 /*!
  * \brief StringHandler::number
- * Helper for QString::number with default precision of 16 instead of 6.
+ * Uses Ryu to format the value.
  * \param value
- * \param hint - default "" otherwise previous value to get a hint on how to format the new one
- * \param format
- * \param precision
  * \return
  */
-QString StringHandler::number(double value, QString hint, char format, int precision)
+QString StringHandler::number(double value)
 {
-  // we have a hint, see if we can use it to display the number in a similar fashion
-  if (hint.contains("e", Qt::CaseInsensitive)) {
-    // we have an e in the hint, attempt to shorten the number!
-    return QString::number(value, format, QLocale::FloatingPointShortest);
-  } else {
-    return QString::number(value, format, precision);
-  }
+  char* buf = ryu_hr_tdzp(value);
+  QString valueStr(buf);
+  free(buf);
+  return valueStr;
 }
 
 /*!
