@@ -40,6 +40,8 @@
 #include "Editors/BaseEditor.h"
 
 #include <QApplication>
+#include <QCryptographicHash>
+#include <QByteArray>
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
 #include <QScreen>
 #else // QT_VERSION_CHECK
@@ -49,9 +51,20 @@
 #include <QStylePainter>
 #include <QPainter>
 #include <QColorDialog>
+#include <QDir>
+#include <QRegExp>
+#ifdef OM_OMEDIT_ENABLE_LIBXML2
+#include <libxml/parser.h>
+#include <libxml/valid.h>
+#else
 #include <QXmlSchema>
 #include <QXmlSchemaValidator>
-#include <QDir>
+#endif
+
+
+extern "C" {
+extern const char* System_openModelicaPlatform();
+}
 
 SplashScreen *SplashScreen::mpInstance = 0;
 
@@ -580,6 +593,30 @@ QString& Utilities::tempDirectory()
   return tmpPath;
 }
 
+/*
+ * \brief Utilities::generateHash
+ * hash the string input
+ * \param input
+ * \return hashprefix with first 4 chars
+*/
+QString Utilities::generateHash(const QString &input)
+{
+    // Convert the input string to a QByteArray
+    QByteArray byteArray = input.toUtf8();
+    // Create a QCryptographicHash object with the desired algorithm (SHA-256 in this case)
+    QCryptographicHash hash(QCryptographicHash::Sha256);
+    // Add the data to be hashed
+    hash.addData(byteArray);
+    // Obtain the resulting hash as a QByteArray
+    QByteArray hashResult = hash.result();
+    // Convert the hash result to a hex string for readability
+    QString hashString = hashResult.toHex();
+    // Extract the first 4 characters
+    QString hashPrefix = hashString.left(4);
+
+    return hashPrefix;
+}
+
 /*!
  * \brief Utilities::getApplicationSettings
  * Returns the application settings object.
@@ -612,6 +649,38 @@ void Utilities::parseCompositeModelText(MessageHandler *pMessageHandler, QString
   schemaFile.close();
   const QByteArray schemaData = schemaText.toUtf8();
 
+#ifdef OM_OMEDIT_ENABLE_LIBXML2
+  xmlDocPtr doc;
+  QByteArray contentsArray(contents.toLocal8Bit());
+  doc = xmlParseDoc((const xmlChar *)contentsArray.data());
+  if (doc)
+  {
+    xmlParserInputBufferPtr buf = xmlParserInputBufferCreateMem(schemaData.data(), schemaData.size(), XML_CHAR_ENCODING_UTF8);
+    xmlDtdPtr dtd = xmlIOParseDTD(NULL, buf, XML_CHAR_ENCODING_UTF8);
+    xmlFreeParserInputBuffer(buf);
+    if (dtd)
+    {
+      xmlValidCtxtPtr vctxt;
+      vctxt = xmlNewValidCtxt();
+      if (vctxt)
+      {
+        int ok = xmlValidateDtd(vctxt, doc, dtd);
+        if (!ok)
+          pMessageHandler->setFailed(true);
+        xmlFreeValidCtxt(vctxt);
+      }
+      else
+        pMessageHandler->setFailed(true);
+      xmlFreeDtd(dtd);
+    }
+    else
+      pMessageHandler->setFailed(true);
+    xmlFreeDoc(doc);
+  }
+  else
+      pMessageHandler->setFailed(true);
+
+#else
   QXmlSchema schema;
   schema.setMessageHandler(pMessageHandler);
   schema.load(schemaData);
@@ -623,6 +692,7 @@ void Utilities::parseCompositeModelText(MessageHandler *pMessageHandler, QString
       pMessageHandler->setFailed(true);
     }
   }
+#endif
 }
 
 /*!
@@ -979,19 +1049,24 @@ QGenericMatrix<3,3, double> Utilities::getRotationMatrix(QGenericMatrix<3,1,doub
 QString Utilities::getGDBPath()
 {
 #if defined(_WIN32)
-#if defined(__MINGW32__) && !defined(__MINGW64__)
-  const char *sgdb = "/tools/msys/mingw32/bin/gdb.exe";
-#endif
-#if defined(__MINGW64__)
-  const char *sgdb = "/tools/msys/mingw64/bin/gdb.exe";
-#endif
   const char *OMDEV = getenv("OMDEV");
-  if (QString(OMDEV).isEmpty()) {
-    return QString(Helper::OpenModelicaHome).append(sgdb);
-  } else {
-    QString qOMDEV = QString(OMDEV).replace("\\", "/");
-    return QString(qOMDEV).append(sgdb);
+  const char *MSYSTEM_PREFIX = getenv("MSYSTEM_PREFIX");
+  const char* msysEnv = System_openModelicaPlatform(); /* "ucrt64" or "mingw64" */
+
+  // MSYSTEM_PREFIX is set: <MSYSTEM_PREFIX>/bin/gdb.exe
+  if (!QString(MSYSTEM_PREFIX).isEmpty()) {
+    QString qMSYSTEM_PREFIX = QString(MSYSTEM_PREFIX).replace("\\", "/");
+    return QString(qMSYSTEM_PREFIX) + QString("/bin/gdb.exe");
   }
+
+  // OMDEV is set: <OMDEV>/tools/msys/<CONFIG_OPENMODELICA_SPEC_PLATFORM>/bin/gdb.exe
+  if (!QString(OMDEV).isEmpty()) {
+    QString qOMDEV = QString(OMDEV).replace("\\", "/");
+    return QString(qOMDEV) + QString("/tools/msys/") + QString(msysEnv) + QString("/bin/gdb.exe");
+  }
+
+  // Default: <OPENMODELICAHOME>/tools/msys/<CONFIG_OPENMODELICA_SPEC_PLATFORM>/bin/gdb.exe
+  return QString(Helper::OpenModelicaHome) + QString("/tools/msys/") + QString(msysEnv) + QString("bin/gdb.exe");
 #else
   return "gdb";
 #endif
@@ -1065,23 +1140,6 @@ bool Utilities::containsWord(QString text, int index, QString keyword, bool chec
   return false;
 }
 
-/*!
- * \brief Utilities::convertMMToPixel
- * Converts the value from mm to pixels
- * pixel = (dpi * mm / 1 inch)
- * 1 inch is 25.4
- * \param value
- * \return
- */
-qreal Utilities::convertMMToPixel(qreal value)
-{
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
-  return (QApplication::primaryScreen()->logicalDotsPerInchX() * value) / 25.4;
-#else // QT_VERSION_CHECK
-  return (QApplication::desktop()->screen()->logicalDpiX() * value) / 25.4;
-#endif // QT_VERSION_CHECK
-}
-
 /*!
  * \brief Utilities::maxi
  * This function gives the maximum
