@@ -37,11 +37,7 @@
 //QT Headers
 #include <QtGlobal>
 #include <QObject>
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
 #include <QtWidgets>
-#else
-#include <QtGui/QMessageBox>
-#endif
 
 //IAEX Headers
 #include "cellcommandcenter.h"
