@@ -64,7 +64,7 @@ PlotWindow::PlotWindow(QStringList arguments, QWidget *parent, bool isInteractiv
 {
   /* set the widget background white. so that the plot is more useable in books and publications. */
   QPalette p(palette());
-  p.setColor(QPalette::Background, Qt::white);
+  p.setColor(QPalette::Window, Qt::white);
   setAutoFillBackground(true);
   setPalette(p);
   // setup the main window widget
@@ -143,8 +143,6 @@ void PlotWindow::initializePlot(QStringList arguments)
   }
   setTimeUnit("");
   setPrefixUnits(true);
-  setCanUseXPrefixUnits(false);
-  setCanUseYPrefixUnits(false);
   /* read variables */
   QStringList variablesToRead;
   for(int i = 18; i < arguments.length(); i++)
@@ -184,11 +182,6 @@ void PlotWindow::setPlotType(PlotType type)
   mPlotType = type;
 }
 
-PlotWindow::PlotType PlotWindow::getPlotType()
-{
-  return mPlotType;
-}
-
 void PlotWindow::initializeFile(QString file)
 {
   mFile.setFileName(file);
@@ -296,6 +289,7 @@ void PlotWindow::setupToolbar()
     mpStartSimulationToolButton->setIcon(QIcon(":/Resources/icons/play_animation.svg"));
     mpStartSimulationToolButton->setToolTip(tr("Start"));
     mpStartSimulationToolButton->setAutoRaise(true);
+    connect(mpStartSimulationToolButton, SIGNAL(clicked(bool)), SLOT(interactiveSimulationStarted()));
     // pause tool button
     mpPauseSimulationToolButton = new QToolButton;
     mpPauseSimulationToolButton->setEnabled(false);
@@ -303,6 +297,7 @@ void PlotWindow::setupToolbar()
     mpPauseSimulationToolButton->setIcon(QIcon(":/Resources/icons/pause.svg"));
     mpPauseSimulationToolButton->setToolTip(tr("Pause"));
     mpPauseSimulationToolButton->setAutoRaise(true);
+    connect(mpPauseSimulationToolButton, SIGNAL(clicked(bool)), SLOT(interactiveSimulationPaused()));
     // speed label and combo box
     mpSimulationSpeedLabel = new QLabel(tr("Speed:"));
     QDoubleValidator *pDoubleValidator = new QDoubleValidator(this);
@@ -395,7 +390,7 @@ void PlotWindow::setupToolbar()
 void PlotWindow::plot(PlotCurve *pPlotCurve)
 {
   QString currentLine;
-  if (mVariablesList.isEmpty() && getPlotType() == PlotWindow::PLOT)
+  if (mVariablesList.isEmpty() && isPlot())
     throw NoVariableException(QString("No variables specified!").toStdString().c_str());
 
   bool editCase = pPlotCurve ? true : false;
@@ -426,7 +421,7 @@ void PlotWindow::plot(PlotCurve *pPlotCurve)
       if (currentLine.contains("DataSet:"))
       {
         currentVariable = currentLine.remove("DataSet: ");
-        if (mVariablesList.contains(currentVariable) || getPlotType() == PlotWindow::PLOTALL)
+        if (mVariablesList.contains(currentVariable) || isPlotAll())
         {
           variablesPlotted.append(currentVariable);
           if (!editCase) {
@@ -446,18 +441,18 @@ void PlotWindow::plot(PlotCurve *pPlotCurve)
             pPlotCurve->addYAxisValue(QString(values[1]).toDouble());
             currentLine = mpTextStream->readLine();
           }
-          pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+          pPlotCurve->plotData();
           pPlotCurve->attach(mpPlot);
           mpPlot->replot();
         }
         // if plottype is PLOT and we have read all the variable we need to plot then simply break the loop
-        if (getPlotType() == PlotWindow::PLOT)
-          if (mVariablesList.size() == variablesPlotted.size())
-            break;
+        if (isPlot() && mVariablesList.size() == variablesPlotted.size()) {
+          break;
+        }
       }
     }
     // if plottype is PLOT then check which requested variables are not found in the file
-    if (getPlotType() == PlotWindow::PLOT)
+    if (isPlot())
       checkForErrors(mVariablesList, variablesPlotted);
     // close the file
     mFile.close();
@@ -488,7 +483,7 @@ void PlotWindow::plot(PlotCurve *pPlotCurve)
     // read in all values
     for (int i = 0; i < csvReader->numvars; i++)
     {
-      if (mVariablesList.contains(csvReader->variables[i]) || getPlotType() == PlotWindow::PLOTALL)
+      if (mVariablesList.contains(csvReader->variables[i]) || isPlotAll())
       {
         variablesPlotted.append(csvReader->variables[i]);
         double *vals = read_csv_dataset(csvReader, csvReader->variables[i]);
@@ -511,13 +506,13 @@ void PlotWindow::plot(PlotCurve *pPlotCurve)
           pPlotCurve->addXAxisValue(timeVals[i]);
           pPlotCurve->addYAxisValue(vals[i]);
         }
-        pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+        pPlotCurve->plotData();
         pPlotCurve->attach(mpPlot);
         mpPlot->replot();
       }
     }
     // if plottype is PLOT then check which requested variables are not found in the file
-    if (getPlotType() == PlotWindow::PLOT)
+    if (isPlot())
       checkForErrors(mVariablesList, variablesPlotted);
     // close the file
     omc_free_csv_reader(csvReader);
@@ -550,7 +545,7 @@ void PlotWindow::plot(PlotCurve *pPlotCurve)
     }
     // read in all values
     for (uint32_t i = 0; i < reader.nall; i++) {
-      if (mVariablesList.contains(reader.allInfo[i].name) || getPlotType() == PlotWindow::PLOTALL) {
+      if (mVariablesList.contains(reader.allInfo[i].name) || isPlotAll()) {
         variablesPlotted.append(reader.allInfo[i].name);
         // create the plot curve for variable
         if (!editCase) {
@@ -579,7 +574,7 @@ void PlotWindow::plot(PlotCurve *pPlotCurve)
             pPlotCurve->addXAxisValue(timeVals[i]);
             pPlotCurve->addYAxisValue(vals[i]);
           }
-          pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+          pPlotCurve->plotData();
           pPlotCurve->attach(mpPlot);
           mpPlot->replot();
         } else { // if variable is a parameter then
@@ -593,14 +588,14 @@ void PlotWindow::plot(PlotCurve *pPlotCurve)
           pPlotCurve->addYAxisValue(val);
           pPlotCurve->addXAxisValue(stopTime);
           pPlotCurve->addYAxisValue(val);
-          pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+          pPlotCurve->plotData();
           pPlotCurve->attach(mpPlot);
           mpPlot->replot();
         }
       }
     }
     // if plottype is PLOT then check which requested variables are not found in the file
-    if (getPlotType() == PlotWindow::PLOT)
+    if (isPlot())
       checkForErrors(mVariablesList, variablesPlotted);
     // close the file
     omc_free_matlab4_reader(&reader);
@@ -691,7 +686,7 @@ void PlotWindow::plotParametric(PlotCurve *pPlotCurve)
             // when two variables are found plot then plot them
             if (variablesPlotted.size() == 2)
             {
-              pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+              pPlotCurve->plotData();
               pPlotCurve->attach(mpPlot);
               mpPlot->replot();
             }
@@ -753,7 +748,7 @@ void PlotWindow::plotParametric(PlotCurve *pPlotCurve)
         pPlotCurve->addXAxisValue(xVals[i]);
         pPlotCurve->addYAxisValue(yVals[i]);
       }
-      pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+      pPlotCurve->plotData();
       pPlotCurve->attach(mpPlot);
       mpPlot->replot();
       // check which requested variables are not found in the file
@@ -801,12 +796,13 @@ void PlotWindow::plotParametric(PlotCurve *pPlotCurve)
       // if variable is a parameter then
       else
       {
-        double xval;
-        if (omc_matlab4_val(&xval,&reader,var,0.0)) {
+        double xVal;
+        if (omc_matlab4_val(&xVal,&reader,var,0.0)) {
           omc_free_matlab4_reader(&reader);
           throw NoVariableException(QString("Parameter doesn't have a value : ").append(xVariable).toStdString().c_str());
         }
-        pPlotCurve->addXAxisValue(xval);
+        for (uint32_t i = 0 ; i < reader.nrows ; i++)
+          pPlotCurve->addXAxisValue(xVal);
       }
       //Fill variable y with data
       var = omc_matlab4_find_var(&reader, yVariable.toStdString().c_str());
@@ -828,14 +824,15 @@ void PlotWindow::plotParametric(PlotCurve *pPlotCurve)
       // if variable is a parameter then
       else
       {
-        double yval;
-        if (omc_matlab4_val(&yval,&reader,var,0.0)) {
+        double yVal;
+        if (omc_matlab4_val(&yVal,&reader,var,0.0)) {
           omc_free_matlab4_reader(&reader);
           throw NoVariableException(QString("Parameter doesn't have a value : ").append(yVariable).toStdString().c_str());
         }
-        pPlotCurve->addYAxisValue(yval);
+        for (uint32_t i = 0 ; i < reader.nrows ; i++)
+          pPlotCurve->addYAxisValue(yVal);
       }
-      pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+      pPlotCurve->plotData();
       pPlotCurve->attach(mpPlot);
       mpPlot->replot();
       omc_free_matlab4_reader(&reader);
@@ -936,7 +933,7 @@ void PlotWindow::plotArray(double time, PlotCurve *pPlotCurve)
   double *res;
   QString currentLine;
   setTime(time);
-  if (mVariablesList.isEmpty() && getPlotType() == PlotWindow::PLOTARRAY)
+  if (mVariablesList.isEmpty() && isPlotArray())
     throw NoVariableException(QString("No variables specified!").toStdString().c_str());
   bool editCase = pPlotCurve ? true : false;
   //PLOT PLT
@@ -994,7 +991,7 @@ void PlotWindow::plotArray(double time, PlotCurve *pPlotCurve)
         pPlotCurve->addXAxisValue(i+1);
         pPlotCurve->addYAxisValue(arrLst[i]);
       }
-      pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+      pPlotCurve->plotData();
       pPlotCurve->attach(mpPlot);
       updateTimeText();
     }
@@ -1053,7 +1050,7 @@ void PlotWindow::plotArray(double time, PlotCurve *pPlotCurve)
         pPlotCurve->addXAxisValue(j+1);
         pPlotCurve->addYAxisValue(res[j]);
       }
-      pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+      pPlotCurve->plotData();
       pPlotCurve->attach(mpPlot);
       updateTimeText();
     }
@@ -1112,13 +1109,13 @@ void PlotWindow::plotArray(double time, PlotCurve *pPlotCurve)
           pPlotCurve->addXAxisValue(i+1);
           pPlotCurve->addYAxisValue(res[i]);
         }
-        pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+        pPlotCurve->plotData();
         pPlotCurve->attach(mpPlot);
         updateTimeText();
         delete[] res;
       }
       // if plottype is PLOT then check which requested variables are not found in the file
-      if (getPlotType() == PlotWindow::PLOT)
+      if (isPlot())
         checkForErrors(mVariablesList, variablesPlotted);
       // close the file
       omc_free_matlab4_reader(&reader);
@@ -1207,7 +1204,7 @@ void PlotWindow::plotArrayParametric(double time, PlotCurve *pPlotCurve)
         pPlotCurve->addXAxisValue(xValsLst[i]);
         pPlotCurve->addYAxisValue(yValsLst[i]);
       }
-      pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+      pPlotCurve->plotData();
       pPlotCurve->attach(mpPlot);
       updateTimeText();
       mFile.close();
@@ -1266,7 +1263,7 @@ void PlotWindow::plotArrayParametric(double time, PlotCurve *pPlotCurve)
             pPlotCurve->addXAxisValue(res[i]);
         }
         else { //yVar
-          if (pPlotCurve->getSize()!=res.count()) {
+          if (pPlotCurve->getXAxisSize()!=res.count()) {
             omc_free_csv_reader(csvReader);
             throw PlotException(tr("Arrays must be of the same length in array parametric plot."));
           }
@@ -1274,7 +1271,7 @@ void PlotWindow::plotArrayParametric(double time, PlotCurve *pPlotCurve)
             pPlotCurve->addYAxisValue(res[i]);
         }
       }
-      pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+      pPlotCurve->plotData();
       pPlotCurve->attach(mpPlot);
       updateTimeText();
       omc_free_csv_reader(csvReader);
@@ -1337,7 +1334,7 @@ void PlotWindow::plotArrayParametric(double time, PlotCurve *pPlotCurve)
           for (int i = 0; i < vars.count(); i++)
             pPlotCurve->addXAxisValue(res[i]);
         else{
-          if (pPlotCurve->getSize()!=vars.count()) {
+          if (pPlotCurve->getXAxisSize()!=vars.count()) {
             omc_free_matlab4_reader(&reader);
             throw PlotException("Arrays must be of the same length in array parametric plot.");
           }
@@ -1346,7 +1343,7 @@ void PlotWindow::plotArrayParametric(double time, PlotCurve *pPlotCurve)
         }
         delete[] res;
       }
-      pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+      pPlotCurve->plotData();
       pPlotCurve->attach(mpPlot);
       updateTimeText();
       omc_free_matlab4_reader(&reader);
@@ -1356,7 +1353,7 @@ void PlotWindow::plotArrayParametric(double time, PlotCurve *pPlotCurve)
 
 QPair<QVector<double>*, QVector<double>*> PlotWindow::plotInteractive(PlotCurve *pPlotCurve)
 {
-  if (mVariablesList.isEmpty() && getPlotType() == PlotWindow::PLOTINTERACTIVE) {
+  if (mVariablesList.isEmpty() && isPlotInteractive()) {
     throw NoVariableException(QString(tr("No variables specified!")).toStdString().c_str());
   } else if (mVariablesList.size() != 1) {
     throw NoVariableException(QString(tr("Could not determine the variable name!")).toStdString().c_str());
@@ -1398,36 +1395,33 @@ void PlotWindow::setTitle(QString title)
   mpPlot->setTitle(title);
 }
 
-void PlotWindow::updateCurves()
-{
-  for (auto & p : mpPlot->getPlotCurvesList()) {
-    // append the last point to the plotting curve
-    p->getPlotDirectPainter()->drawSeries(p, p->getSize() - 2, -1);
-  }
-}
-
-void PlotWindow::updateYAxis(QPair<double, double> minMaxValues)
-{
-  // replot if a value is out of bounds
-  if (minMaxValues.first < mpPlot->axisScaleDiv(QwtPlot::yLeft).lowerBound() || minMaxValues.second > mpPlot->axisScaleDiv(QwtPlot::yLeft).upperBound()) {
-    mpPlot->replot();
-  }
-}
-
 /*!
  * \brief PlotWindow::updatePlot
- * This function is called by OMEdit when auto scale is false.
- * Updates the plot manually.
+ * Updates the plot.
+ * If auto scale is enabled then calls PlotWindow::fitInView()
  */
 void PlotWindow::updatePlot()
 {
-  mpPlot->updateLayout();
-  mpPlot->replot();
-  if (mpPlot->getPlotZoomer()->zoomStack().size() == 1) {
-    mpPlot->getPlotZoomer()->setZoomBase(false);
+  if (mpAutoScaleButton->isChecked()) {
+    fitInView();
+  } else {
+    mpPlot->updateLayout();
+    mpPlot->replot();
+    if (mpPlot->getPlotZoomer()->zoomStack().size() == 1) {
+      mpPlot->getPlotZoomer()->setZoomBase(false);
+    }
   }
 }
 
+void PlotWindow::setInteractiveControls(bool enabled)
+{
+  // control buttons
+  mpStartSimulationToolButton->setEnabled(enabled);
+  mpPauseSimulationToolButton->setEnabled(!enabled);
+  //plotpicker
+  mpPlot->getPlotPicker()->setEnabled(enabled);
+}
+
 void PlotWindow::setGrid(QString grid)
 {
   if (grid.toLower().compare("detailed") == 0) {
@@ -1611,26 +1605,6 @@ void PlotWindow::setPrefixUnits(bool prefixUnits)
   mPrefixUnits = prefixUnits;
 }
 
-bool PlotWindow::canUseXPrefixUnits() const
-{
-  return mCanUseXPrefixUnits;
-}
-
-void PlotWindow::setCanUseXPrefixUnits(bool canUseXPrefixUnits)
-{
-  mCanUseXPrefixUnits = canUseXPrefixUnits;
-}
-
-bool PlotWindow::canUseYPrefixUnits() const
-{
-  return mCanUseYPrefixUnits;
-}
-
-void PlotWindow::setCanUseYPrefixUnits(bool canUseYPrefixUnits)
-{
-  mCanUseYPrefixUnits = canUseYPrefixUnits;
-}
-
 void PlotWindow::checkForErrors(QStringList variables, QStringList variablesPlotted)
 {
   QStringList nonExistingVariables;
@@ -1667,6 +1641,31 @@ void PlotWindow::closeEvent(QCloseEvent *event)
   event->accept();
 }
 
+void PlotWindow::fitInView()
+{
+  mpPlot->getPlotZoomer()->zoom(0);
+  mpPlot->setAxisAutoScale(QwtPlot::yLeft);
+  mpPlot->setAxisAutoScale(QwtPlot::xBottom);
+  mpPlot->replot();
+  mpPlot->getPlotZoomer()->setZoomBase(false);
+}
+
+void PlotWindow::updateCurves()
+{
+  for (auto & p : mpPlot->getPlotCurvesList()) {
+    // append the last point to the plotting curve
+    p->getPlotDirectPainter()->drawSeries(p, p->getXAxisSize() - 2, -1);
+  }
+}
+
+void PlotWindow::updateYAxis(QPair<double, double> minMaxValues)
+{
+  // replot if a value is out of bounds
+  if (minMaxValues.first < mpPlot->axisScaleDiv(QwtPlot::yLeft).lowerBound() || minMaxValues.second > mpPlot->axisScaleDiv(QwtPlot::yLeft).upperBound()) {
+    mpPlot->replot();
+  }
+}
+
 void PlotWindow::enableZoomMode(bool on)
 {
   mpPlot->getPlotZoomer()->setEnabled(on);
@@ -1794,15 +1793,6 @@ void PlotWindow::setGrid(int index)
   mpPlot->replot();
 }
 
-void PlotWindow::fitInView()
-{
-  mpPlot->getPlotZoomer()->zoom(0);
-  mpPlot->setAxisAutoScale(QwtPlot::yLeft);
-  mpPlot->setAxisAutoScale(QwtPlot::xBottom);
-  mpPlot->replot();
-  mpPlot->getPlotZoomer()->setZoomBase(false);
-}
-
 void PlotWindow::setLogX(bool on)
 {
   if (on) {
@@ -1855,7 +1845,7 @@ bool PlotWindow::toggleSign(PlotCurve *pPlotCurve, bool checked)
     for (int i = 0 ; i < pPlotCurve->mYAxisVector.size() ; i++) {
       pPlotCurve->updateYAxisValue(i, -pPlotCurve->mYAxisVector.at(i));
     }
-    pPlotCurve->setData(pPlotCurve->getXAxisVector(), pPlotCurve->getYAxisVector(), pPlotCurve->getSize());
+    pPlotCurve->plotData(true);
     toggleSign = true;
   }
   return toggleSign;
@@ -1874,6 +1864,16 @@ void PlotWindow::showSetupDialog(QString variable)
   pSetupDialog->exec();
 }
 
+void PlotWindow::interactiveSimulationStarted()
+{
+  setInteractiveControls(false);
+}
+
+void PlotWindow::interactiveSimulationPaused()
+{
+  setInteractiveControls(true);
+}
+
 /*!
   \class VariablePageWidget
   \brief Represent the attribute of a plot variable.
@@ -2194,40 +2194,40 @@ void SetupDialog::selectVariable(QString variable)
   }
 }
 
-bool SetupDialog::setupPlotCurve(VariablePageWidget *pVariablePageWidget)
+void SetupDialog::setupPlotCurve(VariablePageWidget *pVariablePageWidget)
 {
-  if (!pVariablePageWidget) {
-    return false;
+  if (pVariablePageWidget) {
+    PlotCurve *pPlotCurve = pVariablePageWidget->getPlotCurve();
+    /* set the legend title */
+    if (pPlotCurve->getCustomTitle().isEmpty() && pPlotCurve->title().text().compare(pVariablePageWidget->getLegendTextBox()->text()) == 0) {
+      pPlotCurve->setCustomTitle("");
+    } else {
+      pPlotCurve->setCustomTitle(pVariablePageWidget->getLegendTextBox()->text());
+    }
+    /* set the curve color title */
+    pPlotCurve->setCustomColor(!pVariablePageWidget->getAutomaticColorCheckBox()->isChecked());
+    if (pVariablePageWidget->getAutomaticColorCheckBox()->isChecked()) {
+      pVariablePageWidget->setCurveColor(pPlotCurve->pen().color());
+      pVariablePageWidget->setCurvePickColorButtonIcon();
+    } else {
+      QPen pen = pPlotCurve->pen();
+      pen.setColor(pVariablePageWidget->getCurveColor());
+      pPlotCurve->setPen(pen);
+    }
+    /* set the curve style */
+    QComboBox *pPatternComboBox = pVariablePageWidget->getPatternComboBox();
+    pPlotCurve->setCurveStyle(pPatternComboBox->itemData(pPatternComboBox->currentIndex()).toInt());
+    /* set the curve width */
+    pPlotCurve->setCurveWidth(pVariablePageWidget->getThicknessSpinBox()->value());
+    /* set the curve visibility */
+    pPlotCurve->toggleVisibility(!pVariablePageWidget->getHideCheckBox()->isChecked());
+    /* set the curve toggle sign */
+    mpPlotWindow->toggleSign(pPlotCurve, pVariablePageWidget->getToggleSignCheckBox()->isChecked());
+    // if prefixunits value is changed
+    if (mPrefixUnitsChanged) {
+      pPlotCurve->plotData();
+    }
   }
-
-  PlotCurve *pPlotCurve = pVariablePageWidget->getPlotCurve();
-
-  /* set the legend title */
-  if (pPlotCurve->getCustomTitle().isEmpty() && pPlotCurve->title().text().compare(pVariablePageWidget->getLegendTextBox()->text()) == 0) {
-    pPlotCurve->setCustomTitle("");
-  } else {
-    pPlotCurve->setCustomTitle(pVariablePageWidget->getLegendTextBox()->text());
-  }
-  /* set the curve color title */
-  pPlotCurve->setCustomColor(!pVariablePageWidget->getAutomaticColorCheckBox()->isChecked());
-  if (pVariablePageWidget->getAutomaticColorCheckBox()->isChecked()) {
-    pVariablePageWidget->setCurveColor(pPlotCurve->pen().color());
-    pVariablePageWidget->setCurvePickColorButtonIcon();
-  } else {
-    QPen pen = pPlotCurve->pen();
-    pen.setColor(pVariablePageWidget->getCurveColor());
-    pPlotCurve->setPen(pen);
-  }
-  /* set the curve style */
-  QComboBox *pPatternComboBox = pVariablePageWidget->getPatternComboBox();
-  pPlotCurve->setCurveStyle(pPatternComboBox->itemData(pPatternComboBox->currentIndex()).toInt());
-  /* set the curve width */
-  pPlotCurve->setCurveWidth(pVariablePageWidget->getThicknessSpinBox()->value());
-  /* set the curve visibility */
-  pPlotCurve->toggleVisibility(!pVariablePageWidget->getHideCheckBox()->isChecked());
-  /* set the curve toggle sign */
-  bool toggleSign = mpPlotWindow->toggleSign(pPlotCurve, pVariablePageWidget->getToggleSignCheckBox()->isChecked());
-  return toggleSign;
 }
 
 void SetupDialog::variableSelected(QListWidgetItem *current, QListWidgetItem *previous)
@@ -2259,13 +2259,12 @@ void SetupDialog::saveSetup()
 
 void SetupDialog::applySetup()
 {
+  // set the prefix units. Always set prefixUnits before setting plot data.
+  mPrefixUnitsChanged = mpPrefixUnitsCheckbox->isChecked() != mpPlotWindow->getPrefixUnits();
+  mpPlotWindow->setPrefixUnits(mpPrefixUnitsCheckbox->isChecked());
   // set the variables attributes
-  bool requiresFitInView = false;
   for (int i = 0 ; i < mpVariablePagesStackedWidget->count() ; i++) {
-    // if any of the variable requires call to fitinview because of toggle sign.
-    if (setupPlotCurve(qobject_cast<VariablePageWidget*>(mpVariablePagesStackedWidget->widget(i)))) {
-      requiresFitInView = true;
-    }
+    setupPlotCurve(qobject_cast<VariablePageWidget*>(mpVariablePagesStackedWidget->widget(i)));
   }
   // set the font sizes. Don't move this line. We should set the font sizes before calling setLegendPosition
   mpPlotWindow->getPlot()->setFontSizes(mpTitleFontSizeSpinBox->value(), mpVerticalAxisTitleFontSizeSpinBox->value(), mpVerticalAxisNumbersFontSizeSpinBox->value(),
@@ -2278,8 +2277,6 @@ void SetupDialog::applySetup()
   mpPlotWindow->setFooter(mpPlotFooterTextBox->text());
   // set the legend
   mpPlotWindow->setLegendPosition(mpLegendPositionComboBox->itemData(mpLegendPositionComboBox->currentIndex()).toString());
-  // set the prefix units
-  mpPlotWindow->setPrefixUnits(mpPrefixUnitsCheckbox->isChecked());
   // set the auto scale
   mpPlotWindow->setAutoScale(mpAutoScaleCheckbox->isChecked());
   // set the range
@@ -2290,9 +2287,6 @@ void SetupDialog::applySetup()
     mpPlotWindow->setXRange(mpXMinimumTextBox->text().toDouble(), mpXMaximumTextBox->text().toDouble());
     mpPlotWindow->setYRange(mpYMinimumTextBox->text().toDouble(), mpYMaximumTextBox->text().toDouble());
   }
-  // replot
-  mpPlotWindow->getPlot()->replot();
-  if (requiresFitInView) {
-    mpPlotWindow->fitInView();
-  }
+  // update plot
+  mpPlotWindow->updatePlot();
 }
