@@ -40,11 +40,11 @@
 #include "SystemTLM.h"
 #include "SystemWC.h"
 
-#include <fmilib.h>
-#include <JM/jm_portability.h>
-#include <RegEx.h>
+#include <fmi4c.h>
+#include <regex>
 #include <unordered_set>
 #include <cmath>
+#include <iostream>
 
 
 oms::ComponentFMUCS::ComponentFMUCS(const ComRef& cref, System* parentSystem, const std::string& fmuPath)
@@ -54,10 +54,12 @@ oms::ComponentFMUCS::ComponentFMUCS(const ComRef& cref, System* parentSystem, co
 
 oms::ComponentFMUCS::~ComponentFMUCS()
 {
-  fmi2_import_free_instance(fmu);
-  fmi2_import_destroy_dllfmu(fmu);
-  fmi2_import_free(fmu);
-  fmi_import_free_context(context);
+  // free the fmihandle only if the model is instantitated, otherwise the model class destructor uses terminate() to free the fmihandle
+  if (oms_modelState_virgin != getModel().getModelState())
+  {
+    fmi2_freeInstance(fmu);
+    fmi4c_freeFmu(fmu);
+  }
 }
 
 oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::System* parentSystem, const std::string& fmuPath, std::string replaceComponent)
@@ -116,16 +118,6 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
     component->setPath(relFMUPath.generic_string());
   }
 
-  //std::cout <<"\nFmuInstances: " << cref.c_str() << "=" << guid_ << "=" << relFMUPath.generic_string();
-
-  component->callbacks.malloc = malloc;
-  component->callbacks.calloc = calloc;
-  component->callbacks.realloc = realloc;
-  component->callbacks.free = free;
-  component->callbacks.logger = oms::fmiLogger;
-  component->callbacks.log_level = jm_log_level_all;
-  component->callbacks.context = 0;
-
   // Copy the resource to the temp directory of the model? We don't want have
   // to copy resources if importing an SSP file or snapshot.
   if (parentSystem->copyResources() && !filesystem::exists(absFMUPath))
@@ -146,24 +138,10 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
     }
   }
 
-  component->context = fmi_import_allocate_context(&component->callbacks);
+  // TODO check for fmu already unpacked or not and read directly modeldescription.xml from unpacked resources
 
-  // check version of FMU
-  fmi_version_enu_t version;
-  if (dirExist)
-    version = fmi_import_get_fmi_version_unzipped(component->context, tempDir.generic_string().c_str());
-  else
-    version = fmi_import_get_fmi_version(component->context, absFMUPath.string().c_str(), component->getTempDir().c_str());
-
-  if (fmi_version_2_0_enu != version)
-  {
-    logError("Unsupported FMI version: " + std::string(fmi_version_to_string(version)));
-    delete component;
-    return NULL;
-  }
-
-  // parse modelDescription.xml
-  component->fmu = fmi2_import_parse_xml(component->context, component->getTempDir().c_str(), 0);
+  // load the fmu and parse modelDescription.xml
+  component->fmu = fmi4c_loadFmu(absFMUPath.string().c_str(), tempDir.generic_string().c_str());
   if (!component->fmu)
   {
     logError("Error parsing modelDescription.xml");
@@ -171,8 +149,15 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
     return NULL;
   }
 
-  fmi2_fmu_kind_enu_t fmuKind = fmi2_import_get_fmu_kind(component->fmu);
-  if (!(fmi2_fmu_kind_cs == fmuKind || fmi2_fmu_kind_me_and_cs == fmuKind))
+  fmiVersion_t version = fmi4c_getFmiVersion(component->fmu);
+  if (fmiVersion2 != version)
+  {
+    logError("Unsupported FMI version: " + version);
+    delete component;
+    return NULL;
+  }
+
+  if (!(fmi2_getSupportsCoSimulation(component->fmu) || fmi2_getSupportsCoSimulation(component->fmu) &&  fmi2_getSupportsModelExchange(component->fmu)))
   {
     logError("FMU \"" + std::string(cref) + "\" doesn't support co-simulation mode.");
     delete component;
@@ -181,53 +166,35 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
 
   // update FMU info
   component->fmuInfo.update(version, component->fmu);
+  component->omsfmi2logger = oms::fmi2logger;
 
-  component->callbackFunctions.logger = oms::fmi2logger;
-  component->callbackFunctions.allocateMemory = calloc;
-  component->callbackFunctions.freeMemory = free;
-  component->callbackFunctions.componentEnvironment = component->fmu;
-  component->callbackFunctions.stepFinished = NULL;
-
-  // create a list of all variables
-  fmi2_import_variable_list_t *varList = fmi2_import_get_variable_list(component->fmu, 0);
-  size_t varListSize = fmi2_import_get_variable_list_size(varList);
-  component->allVariables.reserve(varListSize);
-  component->exportVariables.reserve(varListSize);
-  for (size_t i = 0; i < varListSize; ++i)
+  // create a list of all variables using fmi4c variable structure
+  component->allVariables.reserve(fmi2_getNumberOfVariables(component->fmu));
+  component->exportVariables.reserve(fmi2_getNumberOfVariables(component->fmu));
+  for (unsigned int i = 0; i < fmi2_getNumberOfVariables(component->fmu); ++i)
   {
-    fmi2_import_variable_t* var = fmi2_import_get_variable(varList, i);
-    oms::Variable v(var);
+    oms::Variable v(component->fmu, i);
     if (v.getIndex() != i)
     {
       logError("Index mismatch " + std::to_string(v.getIndex()) + " != " + std::to_string(i) + ".\nPlease report the problem to the dev team: https://github.com/OpenModelica/OMSimulator/issues/new?assignees=&labels=&template=bug_report.md");
-      fmi2_import_free_variable_list(varList);
       delete component;
       return NULL;
     }
+    // extract continuous-time derivatives
+    if (v.isContinuousTimeDer())
+      component->derivatives.push_back(v.getIndex());
+
     component->allVariables.push_back(v);
     component->exportVariables.push_back(true);
   }
-  fmi2_import_free_variable_list(varList);
-
-  // extract continuous-time derivatives
-  varList = fmi2_import_get_derivatives_list(component->fmu);
-  varListSize = fmi2_import_get_variable_list_size(varList);
-  for (size_t i = 0; i < varListSize; ++i)
-  {
-    fmi2_import_variable_t* var = fmi2_import_get_variable(varList, i);
-    size_t originalIndex = fmi2_import_get_variable_original_order(var);
-    component->allVariables[originalIndex].markAsContinuousTimeDer();
-    component->derivatives.push_back(originalIndex);
-  }
-  fmi2_import_free_variable_list(varList);
 
   // mark states and continuous-time states
-  for (size_t i = 0; i < component->allVariables.size(); ++i)
+  for (unsigned int i = 0; i < fmi2_getNumberOfVariables(component->fmu); ++i)
   {
     if (component->allVariables[i].isContinuousTimeDer())
-      component->allVariables[component->allVariables[i].getStateIndex()].markAsContinuousTimeState(i);
+      component->allVariables[component->allVariables[i].getStateIndex()-1].markAsContinuousTimeState(i);
     else if (component->allVariables[i].isDer())
-      component->allVariables[component->allVariables[i].getStateIndex()].markAsState(i);
+      component->allVariables[component->allVariables[i].getStateIndex()-1].markAsState(i);
   }
 
   // create some special variable maps
@@ -292,8 +259,14 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const oms::ComRef& cref, oms::
       std::string unitName = component->values.getUnitFromModeldescription(connectorCref);
       if (!unitName.empty())
         connector->connectorUnits[unitName] = component->values.modeldescriptionUnitDefinitions[unitName];
+
+      // get enumerationTypes
+      std::string enumType = component->values.getEnumerationTypeFromModeldescription(connectorCref);
+      if (!enumType.empty())
+        connector->enumerationName[connectorCref] = enumType;
     }
   }
+
   return component;
 }
 
@@ -336,6 +309,16 @@ oms::Component* oms::ComponentFMUCS::NewComponent(const pugi::xml_node& node, om
           if (!unitName.empty())
             component->connectors.back()->connectorUnits[unitName] = component->values.modeldescriptionUnitDefinitions[unitName];
         }
+        // set enumeration definitions
+        if ((*itConnectors).child(oms::ssp::Version1_0::ssc::enumeration_type))
+        {
+          std::string enumTypeName = (*itConnectors).child(oms::ssp::Version1_0::ssc::enumeration_type).attribute("name").as_string();
+          if (!enumTypeName.empty())
+            component->connectors.back()->enumerationName[component->connectors.back()->getName().c_str()] = enumTypeName;
+
+          // give priority to enum definitions in ssd over modeldescription.xml, it is possible the user might have manually change values in ssd file
+          component->values.importEnumerationDefinitions(ssdNode, enumTypeName);
+        }
       }
     }
     else if(name == oms::ssp::Draft20180219::ssd::element_geometry)
@@ -421,6 +404,11 @@ void oms::ComponentFMUCS::getFilteredUnitDefinitionsToSSD(std::map<std::string,
   return values.getFilteredUnitDefinitionsToSSD(unitDefinitions);
 }
 
+void oms::ComponentFMUCS::getFilteredEnumerationDefinitionsToSSD(std::map<std::string, std::map<std::string, std::string>>& enumerationDefinitions)
+{
+  return values.getFilteredEnumerationDefinitionsToSSD(enumerationDefinitions);
+}
+
 oms_status_enu_t oms::ComponentFMUCS::exportToSSV(pugi::xml_node& ssvNode)
 {
   return values.exportToSSV(ssvNode);
@@ -464,20 +452,14 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_initialUnknowns(
   //dumpInitialUnknowns();
 
   // Check if initial unknowns from modelDescription.xml are the same as in initialUnknownsGraph
-  fmi2_import_variable_list_t* initialUnknowns_ModelStructure;
-  initialUnknowns_ModelStructure = fmi2_import_get_initial_unknowns_list(fmu);
-  size_t N_ModelStructure = fmi2_import_get_variable_list_size(initialUnknowns_ModelStructure);
+  size_t N_ModelStructure = values.modelStructureInitialUnknowns.size();
   size_t N = initialUnknownsGraph.getNodes().size();
 
   bool badInitialUnknowns = false;
 
   std::unordered_set <unsigned int> setA_ModelStructure;
-  for (size_t i=0; i < N_ModelStructure; ++i)
-  {
-    fmi2_xml_variable_t* var_ModelStructure = fmi2_import_get_variable(initialUnknowns_ModelStructure, i);
-    size_t originalIndex = fmi2_import_get_variable_original_order(var_ModelStructure);
-    setA_ModelStructure.insert(originalIndex);
-  }
+  for (const auto &it : values.modelStructureInitialUnknowns)
+    setA_ModelStructure.insert(it.first-1);
 
   std::string missing_unknowns = "";
   for (auto &v : allVariables)
@@ -489,30 +471,28 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_initialUnknowns(
     }
   }
 
-  for (size_t i=0; i < N_ModelStructure; ++i)
+  for (const auto &it : values.modelStructureInitialUnknowns)
   {
-    fmi2_xml_variable_t* var_ModelStructure = fmi2_import_get_variable(initialUnknowns_ModelStructure, i);
-    size_t originalIndex = fmi2_import_get_variable_original_order(var_ModelStructure);
-    const Variable& var_oms = allVariables[originalIndex];
-    oms::ComRef name_fmilib(fmi2_import_get_variable_name(var_ModelStructure));
-
+    const Variable &var_oms = allVariables[it.first - 1];
+    fmi2VariableHandle *var = fmi2_getVariableByIndex(fmu, (it.first - 1));
+    oms::ComRef name_fmilib = fmi2_getVariableName(var);
+    // std::cout << "\nDebug: " << var_oms.getCref().c_str() << "===>" << name_fmilib.c_str() << "===>" << var_oms.isInitialUnknown();
     if (var_oms.getCref() != name_fmilib)
     {
-      missing_unknowns += "\n  * " + std::to_string(originalIndex+1) + ": " + std::string(var_oms.getCref()) + " could not be found";
+      missing_unknowns += "\n  * " + std::to_string(it.first) + ": " + std::string(var_oms.getCref()) + " could not be found";
       badInitialUnknowns = true;
     }
     else if (!var_oms.isInitialUnknown())
     {
-      missing_unknowns += "\n  * " + std::to_string(originalIndex+1) + ": " + std::string(var_oms.getCref()) + " is wrongly listed";
+      missing_unknowns += "\n  * " + std::to_string(it.first) + ": " + std::string(var_oms.getCref()) + " is wrongly listed";
       badInitialUnknowns = true;
     }
   }
 
+
   if (badInitialUnknowns && !Flags::IgnoreInitialUnknowns() && N_ModelStructure > 0)
     logWarning("[" + std::string(getCref()) + ": " + getPath() + "] The FMU lists " + std::to_string(N_ModelStructure) + " initial unknowns and exposes " + std::to_string(N) + " initial unknowns." + missing_unknowns);
 
-  fmi2_import_free_variable_list(initialUnknowns_ModelStructure);
-
   if (badInitialUnknowns)
   {
     if(!Flags::IgnoreInitialUnknowns() && N_ModelStructure > 0)
@@ -531,41 +511,17 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_initialUnknowns(
     }
   }
 
-  size_t *startIndex=NULL, *dependency=NULL;
-  char* factorKind;
-
-  fmi2_import_get_initial_unknowns_dependencies(fmu, &startIndex, &dependency, &factorKind);
-
-  if (!startIndex)
+  // get the initial unknowns dependencies
+  int i = 0;
+  for (const auto &it : values.modelStructureInitialUnknowns)
   {
-    logDebug(std::string(getCref()) + ": " + getPath() + " no dependencies");
-    return oms_status_ok;
-  }
-
-  //logInfo(std::string(getCref()) + ": " + getPath());
-  //std::string buffer = "startIndex(" + std::to_string(N+1) + ")\n";
-  //for (int i=0; i < N; i++)
-  //  buffer += "startIndex[" + std::to_string(i) + "] (" + std::string(initialUnknownsGraph.getNodes()[i]) + ") = " + std::to_string(startIndex[i]) + "\n";
-  //buffer += "startIndex[" + std::to_string(N) + "] = " + std::to_string(startIndex[N]) + "\n";
-  //logInfo(buffer);
-
-  //buffer = "dependency(" + std::to_string(startIndex[N]) + ")\n";
-  //for (int i=0; i < startIndex[N]; i++)
-  //  buffer += "dependency[" + std::to_string(i) + "] = " + std::to_string(dependency[i]) + "\n";
-  //logInfo(buffer);
-
-  //buffer = "factorKind(" + std::to_string(startIndex[N]) + ")\n";
-  //for (int i=0; i < startIndex[N]; i++)
-  //  buffer += "factorKind[" + std::to_string(i) + "] = " + std::string(fmi2_dependency_factor_kind_to_string((fmi2_dependency_factor_kind_enu_t)factorKind[i])) + "\n";
-  //logInfo(buffer);
-
-  for (int i=0; i < N_ModelStructure; i++)
-  {
-    if (startIndex[i] == startIndex[i+1])
-    {
+    //std::cout << "\nInitialUnknowns dependencies: " << it.first << "===>" << it.second.size() << "==>" << values.modelStructureInitialUnknownsDependencyExist[it.first];
+    // no dependencies
+    if (it.second.empty() && values.modelStructureInitialUnknownsDependencyExist[it.first])
       logDebug(std::string(getCref()) + ": " + getPath() + " initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " has no dependencies");
-    }
-    else if ((startIndex[i] + 1 == startIndex[i+1]) && (dependency[startIndex[i]] == 0))
+
+    // dependency attribute not provided in modeldescription.xml, all output depends on all inputs
+    else if (it.second.empty() && !values.modelStructureInitialUnknownsDependencyExist[it.first])
     {
       logDebug(std::string(getCref()) + ": " + getPath() + " initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " depends on all inputs");
       for (const auto& j : inputs)
@@ -573,17 +529,19 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_initialUnknowns(
     }
     else
     {
-      for (size_t j=startIndex[i]; j < startIndex[i+1]; j++)
+      //dependency exist
+      for (const auto &index : it.second)
       {
-        if (dependency[j] < 1 || dependency[j] > allVariables.size())
+        if (index < 1 || index > allVariables.size())
         {
-          logWarning("Initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " has bad dependency on variable with index " + std::to_string(dependency[j]) + " which couldn't be resolved");
+          logWarning("Initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " has bad dependency on variable with index " + std::to_string(index) + " which couldn't be resolved");
           return logError(std::string(getCref()) + ": Erroneous initial unknowns detected in modelDescription.xml\nUse flag --ignoreInitialUnknowns=true to ignore all initial unknowns, but this can cause inflated loop size.");
         }
-        logDebug(std::string(getCref()) + ": " + getPath() + " initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " depends on " + std::string(allVariables[dependency[j] - 1]));
-        initialUnknownsGraph.addEdge(allVariables[dependency[j] - 1].makeConnector(this->getFullCref()), initialUnknownsGraph.getNodes()[i]);
+        logDebug(std::string(getCref()) + ": " + getPath() + " initial unknown " + std::string(initialUnknownsGraph.getNodes()[i]) + " depends on " + std::string(allVariables[index - 1]));
+        initialUnknownsGraph.addEdge(allVariables[index - 1].makeConnector(this->getFullCref()), initialUnknownsGraph.getNodes()[i]);
       }
     }
+    i = i + 1;
   }
 
   return oms_status_ok;
@@ -597,25 +555,24 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_outputs()
     return oms_status_error;
   }
 
-  size_t *startIndex=NULL, *dependency=NULL;
-  char* factorKind;
+  // if (!startIndex)
+  // {
+  //   logDebug(std::string(getCref()) + ": " + getPath() + " no dependencies");
+  //   return oms_status_ok;
+  // }
 
-  fmi2_import_get_outputs_dependencies(fmu, &startIndex, &dependency, &factorKind);
-
-  if (!startIndex)
-  {
-    logDebug(std::string(getCref()) + ": " + getPath() + " no dependencies");
-    return oms_status_ok;
-  }
-
-  for (int i=0; i < outputs.size(); i++)
+  // get the output dependencies
+  int i = 0;
+  for (const auto &it : values.modelStructureOutputs)
   {
     Variable& output = allVariables[outputs[i]];
-    if (startIndex[i] == startIndex[i + 1])
+    // no dependencies
+    if (it.second.empty() && values.modelStructureOutputDependencyExist[it.first])
     {
       logDebug(std::string(getCref()) + ": " + getPath() + " output " + std::string(output) + " has no dependencies");
     }
-    else if ((startIndex[i] + 1 == startIndex[i + 1]) && (dependency[startIndex[i]] == 0))
+    // dependency attribute not provided in modeldescription.xml, all output depends on all inputs
+    else if (it.second.empty() && !values.modelStructureOutputDependencyExist[it.first])
     {
       logDebug(std::string(getCref()) + ": " + getPath() + " output " + std::string(output) + " depends on all");
       for (const auto& j : inputs)
@@ -623,17 +580,18 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_outputs()
     }
     else
     {
-      for (size_t j = startIndex[i]; j < startIndex[i + 1]; j++)
+      for (const auto &index : it.second)
       {
-        if (dependency[j] < 1 || dependency[j] > allVariables.size())
+        if (index < 1 || index > allVariables.size())
         {
-          logWarning("Output " + std::string(output) + " has bad dependency on variable with index " + std::to_string(dependency[j]) + " which couldn't be resolved");
+          logWarning("Output " + std::string(output) + " has bad dependency on variable with index " + std::to_string(index) + " which couldn't be resolved");
           return logError(std::string(getCref()) + ": erroneous dependencies detected in modelDescription.xml");
         }
-        logDebug(std::string(getCref()) + ": " + getPath() + " output " + std::string(output) + " depends on " + std::string(allVariables[dependency[j] - 1]));
-        outputsGraph.addEdge(allVariables[dependency[j] - 1].makeConnector(this->getFullCref()), output.makeConnector(this->getFullCref()));
+        logDebug(std::string(getCref()) + ": " + getPath() + " output " + std::string(output) + " depends on " + std::string(allVariables[index - 1]));
+        outputsGraph.addEdge(allVariables[index - 1].makeConnector(this->getFullCref()), output.makeConnector(this->getFullCref()));
       }
     }
+    i = i + 1;
   }
 
   return oms_status_ok;
@@ -641,17 +599,12 @@ oms_status_enu_t oms::ComponentFMUCS::initializeDependencyGraph_outputs()
 
 oms_status_enu_t oms::ComponentFMUCS::instantiate()
 {
-  jm_status_enu_t jmstatus;
-  fmi2_status_t fmistatus;
-
-  // load the FMU shared library
-  jmstatus = fmi2_import_create_dllfmu(fmu, fmi2_fmu_kind_cs, &callbackFunctions);
-  if (jm_status_error == jmstatus)
-    return logError("Could not load \"" + getPath() + "\" which is associated with \"" + std::string(getFullCref()) + "\"; it may be corrupted or may not support your platform");
-
-  jmstatus = fmi2_import_instantiate(fmu, getCref().c_str(), fmi2_cosimulation, NULL, fmi2_false);
-  if (jm_status_error == jmstatus)
-    return logError_FMUCall("fmi2_import_instantiate", this);
+  if (!fmi2_instantiate(fmu, fmi2CoSimulation, omsfmi2logger, calloc, free, NULL, NULL, fmi2True, fmi2True))
+  {
+    logInfo("fmi2Instantiate() failed");
+    exit(1);
+  }
+  //logInfo("instantiation successfull");
 
   // set start values from local resources
   if (values.hasResources())
@@ -685,11 +638,12 @@ oms_status_enu_t oms::ComponentFMUCS::instantiate()
   time = getModel().getStartTime();
   double relativeTolerance = 0.0;
   dynamic_cast<SystemWC*>(getParentSystem())->getTolerance(NULL, &relativeTolerance);
-  fmistatus = fmi2_import_setup_experiment(fmu, fmi2_true, relativeTolerance, time, fmi2_false, 1.0);
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_setup_experiment", this);
 
-  fmistatus = fmi2_import_enter_initialization_mode(fmu);
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_enter_initialization_mode", this);
+  fmi2Status status = fmi2_setupExperiment(fmu, fmi2True, relativeTolerance, time, fmi2False, 1.0);
+  if (fmi2OK != status) return logError_FMUCall("fmi2_setupExperiment", this);
+
+  fmi2Status status_ = fmi2_enterInitializationMode(fmu);
+  if (fmi2OK != status_) return logError_FMUCall("fmi2_enterInitializationMode", this);
 
   return oms_status_ok;
 }
@@ -848,11 +802,10 @@ oms_status_enu_t oms::ComponentFMUCS::initialize()
   clock.reset();
   CallClock callClock(clock);
 
-  fmi2_status_t fmistatus;
-
   // exitInitialization
-  fmistatus = fmi2_import_exit_initialization_mode(fmu);
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_exit_initialization_mode", this);
+  fmi2Status status = fmi2_exitInitializationMode(fmu);
+
+  if (fmi2OK != status) return logError_FMUCall("fmi2_exitInitializationMode", this);
 
   return oms_status_ok;
 }
@@ -860,31 +813,32 @@ oms_status_enu_t oms::ComponentFMUCS::initialize()
 oms_status_enu_t oms::ComponentFMUCS::terminate()
 {
   freeState();
-
-  fmi2_status_t fmistatus = fmi2_import_terminate(fmu);
-  if (fmi2_status_ok != fmistatus)
+  fmi2Status fmistatus = fmi2_terminate(fmu);
+  if (fmi2OK != fmistatus)
     return logError_Termination(getCref());
 
-  fmi2_import_free_instance(fmu);
-  fmi2_import_destroy_dllfmu(fmu);
+  //logInfo("FMU successfully terminated");
+  fmi2_freeInstance(fmu);
+  // free the dlls
+  fmi4c_freeFmu(fmu);
   return oms_status_ok;
 }
 
 oms_status_enu_t oms::ComponentFMUCS::reset()
 {
-  fmi2_status_t fmistatus = fmi2_import_reset(fmu);
-  if (fmi2_status_ok != fmistatus)
+  fmi2Status fmistatus = fmi2_reset(fmu);
+  if (fmi2OK != fmistatus)
     return logError_ResetFailed(getCref());
 
   // enterInitialization
   time = getModel().getStartTime();
   double relativeTolerance = 0.0;
   dynamic_cast<SystemWC*>(getParentSystem())->getTolerance(NULL, &relativeTolerance);
-  fmistatus = fmi2_import_setup_experiment(fmu, fmi2_true, relativeTolerance, time, fmi2_false, 1.0);
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_setup_experiment", this);
+  fmistatus = fmi2_setupExperiment(fmu, fmi2True, relativeTolerance, time, fmi2False, 1.0);
+  if (fmi2OK != fmistatus) return logError_FMUCall("fmi2_setupExperiment", this);
 
-  fmistatus = fmi2_import_enter_initialization_mode(fmu);
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_enter_initialization_mode", this);
+  fmistatus = fmi2_enterInitializationMode(fmu);
+  if (fmi2OK != fmistatus) return logError_FMUCall("fmi2_enterInitializationMode", this);
 
   return oms_status_ok;
 }
@@ -894,7 +848,6 @@ oms_status_enu_t oms::ComponentFMUCS::stepUntil(double stopTime)
   CallClock callClock(clock);
   System *topLevelSystem = getModel().getTopLevelSystem();
 
-  fmi2_status_t fmistatus;
   double hdef = (stopTime-time) / 1.0;
 
   while (time < stopTime)
@@ -918,8 +871,7 @@ oms_status_enu_t oms::ComponentFMUCS::stepUntil(double stopTime)
         }
       }
     }
-
-    fmistatus = fmi2_import_do_step(fmu, time, hdef, fmi2_true);
+    fmi2Status status = fmi2_doStep(fmu, time, hdef, fmi2True);
     time += hdef;
 
 #if !defined(NO_TLM)
@@ -932,12 +884,12 @@ oms_status_enu_t oms::ComponentFMUCS::stepUntil(double stopTime)
   return oms_status_ok;
 }
 
-oms_status_enu_t oms::ComponentFMUCS::getBoolean(const fmi2_value_reference_t& vr, bool& value)
+oms_status_enu_t oms::ComponentFMUCS::getBoolean(const fmi2ValueReference& vr, bool& value)
 {
   CallClock callClock(clock);
 
   int value_;
-  if (fmi2_status_ok != fmi2_import_get_boolean(fmu, &vr, 1, &value_))
+  if (fmi2OK != fmi2_getBoolean(fmu, &vr, 1, &value_))
     return oms_status_error;
 
   value = value_ ? true : false;
@@ -1020,15 +972,15 @@ oms_status_enu_t oms::ComponentFMUCS::getBoolean(const ComRef& cref, bool& value
   if (!fmu || j < 0)
     return logError_UnknownSignal(getFullCref() + cref);
 
-  fmi2_value_reference_t vr = allVariables[j].getValueReference();
+  fmi2ValueReference vr = allVariables[j].getValueReference();
   return getBoolean(vr, value);
 }
 
-oms_status_enu_t oms::ComponentFMUCS::getInteger(const fmi2_value_reference_t& vr, int& value)
+oms_status_enu_t oms::ComponentFMUCS::getInteger(const fmi2ValueReference& vr, int& value)
 {
   CallClock callClock(clock);
 
-  if (fmi2_status_ok != fmi2_import_get_integer(fmu, &vr, 1, &value))
+  if (fmi2OK != fmi2_getInteger(fmu, &vr, 1, &value))
     return oms_status_error;
 
   return oms_status_ok;
@@ -1110,7 +1062,7 @@ oms_status_enu_t oms::ComponentFMUCS::getInteger(const ComRef& cref, int& value)
   if (!fmu || j < 0)
     return logError_UnknownSignal(getFullCref() + cref);
 
-  fmi2_value_reference_t vr = allVariables[j].getValueReference();
+  fmi2ValueReference vr = allVariables[j].getValueReference();
   return getInteger(vr, value);
 }
 
@@ -1125,11 +1077,11 @@ oms::Variable* oms::ComponentFMUCS::getVariable(const ComRef& cref)
   return NULL;
 }
 
-oms_status_enu_t oms::ComponentFMUCS::getReal(const fmi2_value_reference_t& vr, double& value)
+oms_status_enu_t oms::ComponentFMUCS::getReal(const fmi2ValueReference& vr, double& value)
 {
   CallClock callClock(clock);
 
-  if (fmi2_status_ok != fmi2_import_get_real(fmu, &vr, 1, &value))
+  if (fmi2OK != fmi2_getReal(fmu, &vr, 1, &value))
     return oms_status_error;
 
   if (std::isnan(value))
@@ -1239,15 +1191,16 @@ oms_status_enu_t oms::ComponentFMUCS::getReal(const ComRef& cref, double& value)
   if (!fmu || j < 0)
     return logError_UnknownSignal(getFullCref() + cref);
 
-  fmi2_value_reference_t vr = allVariables[j].getValueReference();
+  fmi2ValueReference vr = allVariables[j].getValueReference();
   return getReal(vr, value);
 }
 
-oms_status_enu_t oms::ComponentFMUCS::getString(const fmi2_value_reference_t& vr, std::string& value)
+oms_status_enu_t oms::ComponentFMUCS::getString(const fmi2ValueReference& vr, std::string& value)
 {
   CallClock callClock(clock);
-  fmi2_string_t str;
-  if (fmi2_status_ok != fmi2_import_get_string(fmu, &vr, 1, &str))
+  fmi2String str;
+
+  if (fmi2OK != fmi2_getString(fmu, &vr, 1, &str))
     return oms_status_error;
 
   value = std::string(str);
@@ -1331,7 +1284,7 @@ oms_status_enu_t oms::ComponentFMUCS::getString(const ComRef& cref, std::string&
   if (!fmu || j < 0)
     return logError_UnknownSignal(getFullCref() + cref);
 
-  fmi2_value_reference_t vr = allVariables[j].getValueReference();
+  fmi2ValueReference vr = allVariables[j].getValueReference();
   return getString(vr, value);
 }
 
@@ -1413,10 +1366,10 @@ oms_status_enu_t oms::ComponentFMUCS::getDirectionalDerivative(const ComRef& unk
     }
   }
 
-  // fmi2_value_reference_t vr_unknown[1] = {5};
-  // fmi2_value_reference_t vr_known[4] = {0, 2, 3, 4};
-  // fmi2_real_t dvknown[4] = {1.0, 1.0, 1.0, 1.0};
-  // fmi2_real_t val;
+  // fmi2ValueReference vr_unknown[1] = {5};
+  // fmi2ValueReference vr_known[4] = {0, 2, 3, 4};
+  // fmi2Real dvknown[4] = {1.0, 1.0, 1.0, 1.0};
+  // fmi2Real val;
   // std::cout << "Get directional derivative_static_1: " << val << std::endl;
   // fmi2_import_get_directional_derivative(fmu, vr_unknown, 1, vr_known, 4, dvknown, &val);
   // std::cout << "\nGet directional derivative_static_2: " << val << std::endl;
@@ -1426,9 +1379,9 @@ oms_status_enu_t oms::ComponentFMUCS::getDirectionalDerivative(const ComRef& unk
 
 oms_status_enu_t oms::ComponentFMUCS::getDirectionalDerivativeHeper(const int unknownIndex, const int knownIndex, const std::vector<int> &dependencyList, double &value)
 {
-  fmi2_value_reference_t vr_unknown = allVariables[unknownIndex].getValueReference();
-  fmi2_value_reference_t *vr_known = (fmi2_value_reference_t *)calloc(dependencyList.size(), sizeof(fmi2_value_reference_t *));
-  fmi2_real_t *dvknown = (fmi2_real_t *)calloc(dependencyList.size(), sizeof(fmi2_real_t *));
+  fmi2ValueReference vr_unknown = allVariables[unknownIndex].getValueReference();
+  fmi2ValueReference *vr_known = (fmi2ValueReference *)calloc(dependencyList.size(), sizeof(fmi2ValueReference *));
+  fmi2Real *dvknown = (fmi2Real *)calloc(dependencyList.size(), sizeof(fmi2Real *));
 
   for (int i = 0; i < dependencyList.size(); i++)
   {
@@ -1444,7 +1397,7 @@ oms_status_enu_t oms::ComponentFMUCS::getDirectionalDerivativeHeper(const int un
       dvknown[i] = 0.0;
   }
 
-  fmi2_import_get_directional_derivative(fmu, &vr_unknown, 1, vr_known, dependencyList.size(), dvknown, &value);
+  fmi2_getDirectionalDerivative(fmu, &vr_unknown, 1, vr_known, dependencyList.size(), dvknown, &value);
 
   free(vr_known);
   free(dvknown);
@@ -1498,7 +1451,7 @@ oms_status_enu_t oms::ComponentFMUCS::setRealInputDerivative(const ComRef& cref,
   if (!fmu || j < 0)
     return logError_UnknownSignal(getFullCref() + cref);
 
-  fmi2_value_reference_t vr = allVariables[j].getValueReference();
+  fmi2ValueReference vr = allVariables[j].getValueReference();
   return der.setRealInputDerivatives(fmu, vr);
 }
 
@@ -1544,9 +1497,9 @@ oms_status_enu_t oms::ComponentFMUCS::setBoolean(const ComRef& cref, bool value)
   }
   else
   {
-    fmi2_value_reference_t vr = allVariables[j].getValueReference();
+    fmi2ValueReference vr = allVariables[j].getValueReference();
     int value_ = value ? 1 : 0;
-    if (fmi2_status_ok != fmi2_import_set_boolean(fmu, &vr, 1, &value_))
+    if (fmi2OK != fmi2_setBoolean(fmu, &vr, 1, &value_))
       return oms_status_error;
   }
 
@@ -1596,8 +1549,8 @@ oms_status_enu_t oms::ComponentFMUCS::setInteger(const ComRef& cref, int value)
   }
   else
   {
-    fmi2_value_reference_t vr = allVariables[j].getValueReference();
-    if (fmi2_status_ok != fmi2_import_set_integer(fmu, &vr, 1, &value))
+    fmi2ValueReference vr = allVariables[j].getValueReference();
+    if (fmi2OK != fmi2_setInteger(fmu, &vr, 1, &value))
       return oms_status_error;
   }
 
@@ -1654,8 +1607,8 @@ oms_status_enu_t oms::ComponentFMUCS::setReal(const ComRef& cref, double value)
   }
   else
   {
-    fmi2_value_reference_t vr = allVariables[j].getValueReference();
-    if (fmi2_status_ok != fmi2_import_set_real(fmu, &vr, 1, &value))
+    fmi2ValueReference vr = allVariables[j].getValueReference();
+    if (fmi2OK != fmi2_setReal(fmu, &vr, 1, &value))
       return oms_status_error;
   }
 
@@ -1708,9 +1661,9 @@ oms_status_enu_t oms::ComponentFMUCS::setString(const ComRef& cref, const std::s
   }
   else
   {
-    fmi2_value_reference_t vr = allVariables[j].getValueReference();
-    fmi2_string_t value_ = value.c_str();
-    if (fmi2_status_ok != fmi2_import_set_string(fmu, &vr, 1, &value_))
+    fmi2ValueReference vr = allVariables[j].getValueReference();
+    fmi2String value_ = value.c_str();
+    if (fmi2OK != fmi2_setString(fmu, &vr, 1, &value_))
       return oms_status_error;
   }
 
@@ -1783,15 +1736,17 @@ oms_status_enu_t oms::ComponentFMUCS::deleteStartValue(const ComRef& cref)
   return oms_status_error;
 }
 
-oms_status_enu_t oms::ComponentFMUCS::setValuesResources(std::vector<Values>& allValuesResources)
+oms_status_enu_t oms::ComponentFMUCS::setValuesResources(Values& values)
 {
-  this->values.parameterResources = allValuesResources;
-  return oms_status_ok;
-}
+  // set all ssv and ssm resources from the old component to replacing component
+  this->values.parameterResources = values.parameterResources;
+  // set all user define values from the old component to replacing component as user defined values have higher priority
+  // over modeldescription.xml
+  this->values.realStartValues = values.realStartValues;
+  this->values.integerStartValues = values.integerValues;
+  this->values.booleanStartValues = values.booleanStartValues;
 
-std::vector<oms::Values> oms::ComponentFMUCS::getValuesResources()
-{
-  return this->values.parameterResources;
+  return oms_status_ok;
 }
 
 oms_status_enu_t oms::ComponentFMUCS::updateOrDeleteStartValueInReplacedComponent(std::vector<std::string>& warningList)
@@ -1898,7 +1853,7 @@ oms_status_enu_t oms::ComponentFMUCS::updateSignals(ResultWriter& resultWriter)
   {
     unsigned int ID = it.first;
     Variable& var = allVariables[it.second];
-    fmi2_value_reference_t vr = var.getValueReference();
+    fmi2ValueReference vr = var.getValueReference();
     SignalValue_t value;
     if (var.isTypeReal())
     {
@@ -1925,7 +1880,7 @@ oms_status_enu_t oms::ComponentFMUCS::updateSignals(ResultWriter& resultWriter)
 
 oms_status_enu_t oms::ComponentFMUCS::addSignalsToResults(const char* regex)
 {
-  oms_regex exp(regex);
+  std::regex exp(regex);
   for (unsigned int i=0; i<allVariables.size(); ++i)
   {
     if (exportVariables[i])
@@ -1944,7 +1899,7 @@ oms_status_enu_t oms::ComponentFMUCS::addSignalsToResults(const char* regex)
 
 oms_status_enu_t oms::ComponentFMUCS::removeSignalsFromResults(const char* regex)
 {
-  oms_regex exp(regex);
+  std::regex exp(regex);
   for (unsigned int i=0; i<allVariables.size(); ++i)
   {
     if (!exportVariables[i])
@@ -1963,8 +1918,8 @@ oms_status_enu_t oms::ComponentFMUCS::removeSignalsFromResults(const char* regex
 
 oms_status_enu_t oms::ComponentFMUCS::saveState()
 {
-  fmi2_status_t fmistatus = fmi2_import_get_fmu_state(fmu, &fmuState);
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_get_fmu_state", this);
+  fmi2Status fmistatus = fmi2_getFMUstate(fmu, &fmuState);
+  if (fmi2OK != fmistatus) return logError_FMUCall("fmi2_getFMUstate", this);
   fmuStateTime = time;
 
   return oms_status_ok;
@@ -1975,17 +1930,17 @@ oms_status_enu_t oms::ComponentFMUCS::freeState()
   if (!fmuState)
     return oms_status_warning;
 
-  fmi2_status_t fmistatus = fmi2_import_free_fmu_state(fmu, &fmuState);
+  fmi2Status fmistatus = fmi2_freeFMUstate(fmu, &fmuState);
   fmuState = NULL;
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_free_fmu_state", this);
+  if (fmi2OK != fmistatus) return logError_FMUCall("fmi2_freeFMUstate", this);
 
   return oms_status_ok;
 }
 
 oms_status_enu_t oms::ComponentFMUCS::restoreState()
 {
-  fmi2_status_t fmistatus = fmi2_import_set_fmu_state(fmu, fmuState);
-  if (fmi2_status_ok != fmistatus) return logError_FMUCall("fmi2_import_set_fmu_state", this);
+  fmi2Status fmistatus = fmi2_setFMUstate(fmu, fmuState);
+  if (fmi2OK != fmistatus) return logError_FMUCall("fmi2_setFMUstate", this);
   time = fmuStateTime;
 
   return oms_status_ok;
