@@ -41,7 +41,7 @@
 #include "ssd/Tags.h"
 #include "System.h"
 
-#include <minizip.h>
+#include "minizip.h"
 #include <thread>
 
 oms::Model::Model(const oms::ComRef& cref, const std::string& tempDir)
@@ -510,6 +510,12 @@ oms_status_enu_t oms::Model::exportSSVTemplate(const oms::ComRef& cref, const st
 
   for (const auto& component : system->getComponents())
   {
+    // skip csv files for top level model and export the remaining fmus in the model
+    if (cref.isEmpty())
+    {
+      if (component.second->getType() == oms_component_table)
+        continue;
+    }
     if(component.first == tail || cref.isEmpty() || cref.isValidIdent()) // allow querying single component or whole model
     {
       if (oms_status_ok != component.second->exportToSSVTemplate(ssvNode, snapshot))
@@ -528,6 +534,12 @@ oms_status_enu_t oms::Model::exportSSVTemplate(const oms::ComRef& cref, const st
   {
     for (const auto &component : subsytem.second->getComponents())
     {
+      // skip csv files for top level model and export the remaining fmus in the model
+      if (cref.isEmpty())
+      {
+        if (component.second->getType() == oms_component_table)
+          continue;
+      }
       if (component.first == tailA || cref.isEmpty() || (system->getSystem(frontA) && tailA.isEmpty()))
       {
         if (oms_status_ok != component.second->exportToSSVTemplate(ssvNode, snapshot))
@@ -818,7 +830,7 @@ oms_status_enu_t oms::Model::exportToSSD(Snapshot& snapshot) const
     if (oms_status_ok != system->exportToSSD(system_node, snapshot, this->variantName))
       return logError("export of system failed");
   }
-
+  exportEnumerationDefinitionsToSSD(ssdNode);
   exportUnitDefinitionsToSSD(ssdNode);
 
   pugi::xml_node default_experiment = ssdNode.append_child(oms::ssp::Draft20180219::ssd::default_experiment);
@@ -878,6 +890,10 @@ oms_status_enu_t oms::Model::importFromSnapshot(const Snapshot& snapshot)
     {
       // allow importing unitDefinitions, the unitDefinitions are handled in Values.cpp importFromSnapshot
     }
+    else if (name == oms::ssp::Draft20180219::ssd::enumerations)
+    {
+      // allow importing enumerations, the enumerationDefinitions are handled in Values.cpp importFromSnapshot
+    }
     else if (name == oms::ssp::Draft20180219::ssd::default_experiment)
     {
       startTime = it->attribute("startTime").as_double(0.0);
@@ -1508,6 +1524,34 @@ void oms::Model::exportUnitDefinitionsToSSD(pugi::xml_node& node) const
   }
 }
 
+void oms::Model::exportEnumerationDefinitionsToSSD(pugi::xml_node& node) const
+{
+  if (!system)
+    return;
+
+  std::map<std::string, std::map<std::string, std::string>> enumerationDefinitions;
+  for (const auto& component : system->getComponents())
+    component.second->getFilteredEnumerationDefinitionsToSSD(enumerationDefinitions);
+
+  if (enumerationDefinitions.empty())
+    return;
+
+  pugi::xml_node node_enumeration = node.append_child(oms::ssp::Draft20180219::ssd::enumerations);
+
+  for (const auto &it : enumerationDefinitions)
+  {
+    pugi::xml_node ssc_enumeration = node_enumeration.append_child(oms::ssp::Version1_0::ssc::enumeration_type);
+    ssc_enumeration.append_attribute("name") = it.first.c_str();
+    for (const auto & item: it.second)
+    {
+      pugi::xml_node enumItem = ssc_enumeration.append_child(oms::ssp::Version1_0::ssc::enum_item);
+      enumItem.append_attribute("name") = item.first.c_str();
+      enumItem.append_attribute("value") = item.second.c_str();
+    }
+  }
+
+}
+
 oms_status_enu_t oms::Model::importSignalFilter(const std::string& filename, const Snapshot& snapshot)
 {
   if (".*" == filename) // avoid error messages for older ssp files
